@@ -3,24 +3,30 @@
 /**
  * imap_general.php
  *
- * Copyright (c) 1999-2004 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * This implements all functions that do general imap functions.
+ * This implements all functions that do general IMAP functions.
  *
- * $Id: imap_general.php,v 1.140.2.14 2004/05/02 13:54:36 stekkel Exp $
+ * @version $Id: imap_general.php,v 1.140.2.29 2005/05/20 10:37:34 kink Exp $
+ * @package squirrelmail
+ * @subpackage imap
  */
 
+/** Includes.. */
 require_once(SM_PATH . 'functions/page_header.php');
 require_once(SM_PATH . 'functions/auth.php');
 
 
-global $sqimap_session_id;
-$sqimap_session_id = 1;
+/**
+ * Generates a new session ID by incrementing the last one used;
+ * this ensures that each command has a unique ID.
+ * @param bool unique_id
+ * @return string IMAP session id of the form 'A000'.
+ */
+function sqimap_session_id($unique_id = FALSE) {
+    static $sqimap_session_id = 1;
 
-/* Sets an unique session id in order to avoid simultanous sessions crash. */
-function sqimap_session_id($unique_id = false) {
-    global $data_dir, $username, $sqimap_session_id;
     if (!$unique_id) {
         return( sprintf("A%03d", $sqimap_session_id++) );
     } else {
@@ -28,7 +34,7 @@ function sqimap_session_id($unique_id = false) {
     }
 }
 
-/*
+/**
  * Both send a command and accept the result from the command.
  * This is to allow proper session number handling.
  */
@@ -42,16 +48,15 @@ function sqimap_run_command_list ($imap_stream, $query, $handle_errors, &$respon
         global $squirrelmail_language, $color;
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
-        $string = "<b><font color=$color[2]>\n" .
-                _("ERROR : No available imapstream.") .
+        $string = "<b><font color=\"$color[2]\">\n" .
+                _("ERROR: No available IMAP stream.") .
                 "</b></font>\n";
         error_box($string,$color);
         return false;
     }
-    
 }
 
-function sqimap_run_command ($imap_stream, $query, $handle_errors, &$response, 
+function sqimap_run_command ($imap_stream, $query, $handle_errors, &$response,
                             &$message, $unique_id = false,$filter=false,
                              $outputstream=false,$no_return=false) {
     if ($imap_stream) {
@@ -64,21 +69,21 @@ function sqimap_run_command ($imap_stream, $query, $handle_errors, &$response,
         global $squirrelmail_language, $color;
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
-        $string = "<b><font color=$color[2]>\n" .
-                _("ERROR : No available imapstream.") .
+        $string = "<b><font color=\"$color[2]\">\n" .
+                _("ERROR: No available IMAP stream.") .
                 "</b></font>\n";
         error_box($string,$color);
         return false;
     }
-    
 }
 
 
-/* 
- * custom fgets function. gets a line from IMAP
- * no matter how big it may be
+/**
+ * Custom fgets function: gets a line from the IMAP server,
+ * no matter how big it may be.
+ * @param stream imap_stream the stream to read from
+ * @return string a line
  */
-
 function sqimap_fgets($imap_stream) {
     $read = '';
     $buffer = 4096;
@@ -114,7 +119,7 @@ function sqimap_fread($imap_stream,$iSize,$filter=false,
     $iRetrieved = 0;
     $results = '';
     $sRead = $sReadRem = '';
-    // NB: fread can also stop at end of a packet on sockets. 
+    // NB: fread can also stop at end of a packet on sockets.
     while ($iRetrieved < $iSize) {
         $sRead = fread($imap_stream,$iBufferSize);
         $iLength = strlen($sRead);
@@ -123,20 +128,20 @@ function sqimap_fread($imap_stream,$iSize,$filter=false,
         if ($iRemaining < $iBufferSize) {
             $iBufferSize = $iRemaining;
         }
-        if (!$sRead) {
+        if ($sRead == '') {
             $results = false;
             break;
         }
-        if ($sReadRem) {
+        if ($sReadRem != '') {
             $sRead = $sReadRem . $sRead;
             $sReadRem = '';
         }
 
-        if ($filter && $sRead) {
-           // in case the filter is base64 decoding we return a remainder 
+        if ($filter && $sRead != '') {
+           // in case the filter is base64 decoding we return a remainder
            $sReadRem = $filter($sRead);
         }
-        if ($outputstream && $sRead) {
+        if ($outputstream && $sRead != '') {
            if (is_resource($outputstream)) {
                fwrite($outputstream,$sRead);
            } else if ($outputstream == 'php://stdout') {
@@ -145,20 +150,19 @@ function sqimap_fread($imap_stream,$iSize,$filter=false,
         }
         if ($no_return) {
             $sRead = '';
-        } else {    
+        } else {
             $results .= $sRead;
         }
     }
-    return $results;       
-}        
+    return $results;
+}
 
-/*
+/**
  * Reads the output from the IMAP stream.  If handle_errors is set to true,
  * this will also handle all errors that are received.  If it is not set,
- * the errors will be sent back through $response and $message
+ * the errors will be sent back through $response and $message.
  */
-
-function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors, 
+function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
           &$response, &$message, $query = '',
            $filter = false, $outputstream = false, $no_return = false) {
     global $color, $squirrelmail_language;
@@ -199,7 +203,7 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
                     $response = $arg;
                     $message = trim(substr($read,$i+strlen($arg)));
                     break 3; /* switch switch while */
-                  default: 
+                  default:
                     /* this shouldn't happen */
                     $response = $arg;
                     $message = trim(substr($read,$i+strlen($arg)));
@@ -241,7 +245,7 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
                                 $fetch_data[] = $line ."\n";
                             }
                             /* release not neaded data */
-                            unset($aLiteral); 
+                            unset($aLiteral);
                             /* next fgets belongs to this fetch because
                                we just got the exact literalsize and there
                                must follow data to complete the response */
@@ -300,133 +304,128 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
           } // end case '*'
         }   // end switch
     } // end while
-    
+
     /* error processing in case $read is false */
     if ($read === false) {
         unset($data);
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
-        $string = "<b><font color=$color[2]>\n" .
-                  _("ERROR : Connection dropped by imap-server.") .
-                  "</b><br>\n";
+        $string = "<b><font color=\"$color[2]\">\n" .
+                  _("ERROR: Connection dropped by IMAP server.") .
+                  "</b><br />\n";
         $cmd = explode(' ',$query);
         $cmd = strtolower($cmd[0]);
         if ($query != '' &&  $cmd != 'login') {
             $string .= ("Query:") . ' '. htmlspecialchars($query)
-            . '<br>' . "</font><br>\n";
+            . '<br />' . "</font><br />\n";
         }
-        error_box($string,$color);    
+        error_box($string,$color);
         exit;
     }
-    
+
     /* Set $resultlist array */
     if (!empty($data)) {
         $resultlist[] = $data;
     }
     elseif (empty($resultlist)) {
-        $resultlist[] = array(); 
+        $resultlist[] = array();
     }
 
     /* Return result or handle errors */
     if ($handle_errors == false) {
         return( $resultlist );
     }
-    switch ($response)
-    {
+    switch ($response) {
     case 'OK':
         return $resultlist;
         break;
-    case 'NO': 
+    case 'NO':
         /* ignore this error from M$ exchange, it is not fatal (aka bug) */
         if (strstr($message, 'command resulted in') === false) {
             set_up_language($squirrelmail_language);
             require_once(SM_PATH . 'functions/display_messages.php');
-            $string = "<b><font color=$color[2]>\n" .
-                _("ERROR : Could not complete request.") .
-                "</b><br>\n" .
+            $string = "<b><font color=\"$color[2]\">\n" .
+                _("ERROR: Could not complete request.") .
+                "</b><br />\n" .
                 _("Query:") . ' ' .
-                htmlspecialchars($query) . '<br>' .
-                _("Reason Given: ") .
-                htmlspecialchars($message) . "</font><br>\n";
+                htmlspecialchars($query) . '<br />' .
+                _("Reason Given:") . ' ' .
+                htmlspecialchars($message) . "</font><br />\n";
             error_box($string,$color);
             echo '</body></html>';
             exit;
         }
         break;
-    case 'BAD': 
+    case 'BAD':
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
-        $string = "<b><font color=$color[2]>\n" .
-            _("ERROR : Bad or malformed request.") .
-            "</b><br>\n" .
+        $string = "<b><font color=\"$color[2]\">\n" .
+            _("ERROR: Bad or malformed request.") .
+            "</b><br />\n" .
             _("Query:") . ' '.
-            htmlspecialchars($query) . '<br>' .
-            _("Server responded: ") .
-            htmlspecialchars($message) . "</font><br>\n";
+            htmlspecialchars($query) . '<br />' .
+            _("Server responded:") . ' ' .
+            htmlspecialchars($message) . "</font><br />\n";
         error_box($string,$color);
-        echo '</body></html>';        
-        exit; 
-    case 'BYE': 
-        set_up_language($squirrelmail_language);
-        require_once(SM_PATH . 'functions/display_messages.php');
-        $string = "<b><font color=$color[2]>\n" .
-            _("ERROR : Imap server closed the connection.") .
-            "</b><br>\n" .
-            _("Query:") . ' '.
-            htmlspecialchars($query) . '<br>' .
-            _("Server responded: ") .
-            htmlspecialchars($message) . "</font><br>\n";
-        error_box($string,$color);
-        echo '</body></html>';        
+        echo '</body></html>';
         exit;
-    default: 
+    case 'BYE':
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
-        $string = "<b><font color=$color[2]>\n" .
-            _("ERROR : Unknown imap response.") .
-            "</b><br>\n" .
+        $string = "<b><font color=\"$color[2]\">\n" .
+            _("ERROR: IMAP server closed the connection.") .
+            "</b><br />\n" .
             _("Query:") . ' '.
-            htmlspecialchars($query) . '<br>' .
-            _("Server responded: ") .
-            htmlspecialchars($message) . "</font><br>\n";
+            htmlspecialchars($query) . '<br />' .
+            _("Server responded:") . ' ' .
+            htmlspecialchars($message) . "</font><br />\n";
+        error_box($string,$color);
+        echo '</body></html>';
+        exit;
+    default:
+        set_up_language($squirrelmail_language);
+        require_once(SM_PATH . 'functions/display_messages.php');
+        $string = "<b><font color=\"$color[2]\">\n" .
+            _("ERROR: Unknown IMAP response.") .
+            "</b><br />\n" .
+            _("Query:") . ' '.
+            htmlspecialchars($query) . '<br />' .
+            _("Server responded:") . ' ' .
+            htmlspecialchars($message) . "</font><br />\n";
         error_box($string,$color);
        /* the error is displayed but because we don't know the reponse we
           return the result anyway */
-       return $resultlist;    
+       return $resultlist;
        break;
     }
 }
 
-function sqimap_read_data ($imap_stream, $tag_uid, $handle_errors, 
+function sqimap_read_data ($imap_stream, $tag_uid, $handle_errors,
                            &$response, &$message, $query = '',
                            $filter=false,$outputstream=false,$no_return=false) {
-    $res = sqimap_read_data_list($imap_stream, $tag_uid, $handle_errors, 
-              $response, $message, $query,$filter,$outputstream,$no_return); 
+
+    $res = sqimap_read_data_list($imap_stream, $tag_uid, $handle_errors,
+              $response, $message, $query,$filter,$outputstream,$no_return);
     /* sqimap_read_data should be called for one response
-       but since it just calls sqimap_read_data_list which 
+       but since it just calls sqimap_read_data_list which
        handles multiple responses we need to check for that
-       and merge the $res array IF they are seperated and 
+       and merge the $res array IF they are seperated and
        IF it was a FETCH response. */
-  
-//    if (isset($res[1]) && is_array($res[1]) && isset($res[1][0]) 
+
+//    if (isset($res[1]) && is_array($res[1]) && isset($res[1][0])
 //        && preg_match('/^\* \d+ FETCH/', $res[1][0])) {
 //        $result = array();
 //        foreach($res as $index=>$value) {
 //            $result = array_merge($result, $res["$index"]);
 //        }
 //    }
-    if (isset($result)) {
-        return $result;
-    }
-    else {
-        return $res[0];
-    }
 
+    return $res[0];
 }
 
-/*
- * Logs the user into the imap server.  If $hide is set, no error messages
- * will be displayed.  This function returns the imap connection handle.
+/**
+ * Logs the user into the IMAP server.  If $hide is set, no error messages
+ * will be displayed.  This function returns the IMAP connection handle.
  */
 function sqimap_login ($username, $password, $imap_server_address, $imap_port, $hide) {
     global $color, $squirrelmail_language, $onetimepad, $use_imap_tls, $imap_auth_mech;
@@ -436,23 +435,22 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
     }
     $imap_server_address = sqimap_get_user_server($imap_server_address, $username);
         $host=$imap_server_address;
-        
+
         if (($use_imap_tls == true) and (check_php_version(4,3)) and (extension_loaded('openssl'))) {
           /* Use TLS by prefixing "tls://" to the hostname */
           $imap_server_address = 'tls://' . $imap_server_address;
         }
-    
-    $imap_stream = fsockopen ( $imap_server_address, $imap_port, $error_number, $error_string, 15);
+
+    $imap_stream = @fsockopen($imap_server_address, $imap_port, $error_number, $error_string, 15);
 
     /* Do some error correction */
     if (!$imap_stream) {
         if (!$hide) {
             set_up_language($squirrelmail_language, true);
             require_once(SM_PATH . 'functions/display_messages.php');
-            $string = sprintf (_("Error connecting to IMAP server: %s.") .
-                              "<br>\r\n", $imap_server_address) .
-                      "$error_number : $error_string<br>\r\n";
-            logout_error($string,$color);
+            logout_error( sprintf(_("Error connecting to IMAP server: %s."), $imap_server_address).
+                "<br />\r\n$error_number : $error_string<br />\r\n",
+		sprintf(_("Error connecting to IMAP server: %s."), $imap_server_address) );
         }
         exit;
     }
@@ -462,58 +460,81 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
     /* Decrypt the password */
     $password = OneTimePadDecrypt($password, $onetimepad);
 
-        if (($imap_auth_mech == 'cram-md5') OR ($imap_auth_mech == 'digest-md5')) {
-      // We're using some sort of authentication OTHER than plain or login
-          $tag=sqimap_session_id(false);
-          if ($imap_auth_mech == 'digest-md5') {
+    if (($imap_auth_mech == 'cram-md5') OR ($imap_auth_mech == 'digest-md5')) {
+        // We're using some sort of authentication OTHER than plain or login
+        $tag=sqimap_session_id(false);
+        if ($imap_auth_mech == 'digest-md5') {
             $query = $tag . " AUTHENTICATE DIGEST-MD5\r\n";
-          } elseif ($imap_auth_mech == 'cram-md5') {
+        } elseif ($imap_auth_mech == 'cram-md5') {
             $query = $tag . " AUTHENTICATE CRAM-MD5\r\n";
-          }
-          fputs($imap_stream,$query);
-          $answer=sqimap_fgets($imap_stream);
-          // Trim the "+ " off the front
-          $response=explode(" ",$answer,3);
-          if ($response[0] == '+') {
+        }
+        fputs($imap_stream,$query);
+        $answer=sqimap_fgets($imap_stream);
+        // Trim the "+ " off the front
+        $response=explode(" ",$answer,3);
+        if ($response[0] == '+') {
             // Got a challenge back
-                $challenge=$response[1];
-                if ($imap_auth_mech == 'digest-md5') {
-                  $reply = digest_md5_response($username,$password,$challenge,'imap',$host);
-                } elseif ($imap_auth_mech == 'cram-md5') {
-                  $reply = cram_md5_response($username,$password,$challenge);
-                }
-                fputs($imap_stream,$reply);
-                $read=sqimap_fgets($imap_stream);
-                if ($imap_auth_mech == 'digest-md5') {
-                  // DIGEST-MD5 has an extra step..
-                  if (substr($read,0,1) == '+') { // OK so far..
+            $challenge=$response[1];
+            if ($imap_auth_mech == 'digest-md5') {
+                $reply = digest_md5_response($username,$password,$challenge,'imap',$host);
+            } elseif ($imap_auth_mech == 'cram-md5') {
+                $reply = cram_md5_response($username,$password,$challenge);
+            }
+            fputs($imap_stream,$reply);
+            $read=sqimap_fgets($imap_stream);
+            if ($imap_auth_mech == 'digest-md5') {
+                // DIGEST-MD5 has an extra step..
+                if (substr($read,0,1) == '+') { // OK so far..
                     fputs($imap_stream,"\r\n");
                     $read=sqimap_fgets($imap_stream);
-                  }
                 }
-                $results=explode(" ",$read,3);
-                $response=$results[1];
-                $message=$results[2];
-      } else {
-                // Fake the response, so the error trap at the bottom will work
-                $response="BAD";
-                $message='IMAP server does not appear to support the authentication method selected.';
-                $message .= '  Please contact your system administrator.';
-      }
-    } elseif ($imap_auth_mech == 'login') {
-          // Original IMAP login code
-      $query = 'LOGIN "' . quoteimap($username) .  '" "' . quoteimap($password) . '"';
-      $read = sqimap_run_command ($imap_stream, $query, false, $response, $message);
-    } elseif ($imap_auth_mech == 'plain') {
-                /* Replace this with SASL PLAIN if it ever gets implemented */
-                $response="BAD";
-                $message='SquirrelMail does not support SASL PLAIN yet. Rerun conf.pl and use login instead.';
+            }
+            $results=explode(" ",$read,3);
+            $response=$results[1];
+            $message=$results[2];
         } else {
-                $response="BAD";
-                $message="Internal SquirrelMail error - unknown IMAP authentication method chosen.  Please contact the developers.";
+            // Fake the response, so the error trap at the bottom will work
+            $response="BAD";
+            $message='IMAP server does not appear to support the authentication method selected.';
+            $message .= '  Please contact your system administrator.';
         }
-    
-        /* If the connection was not successful, lets see why */
+    } elseif ($imap_auth_mech == 'login') {
+        // this is a workaround to alert users of LOGINDISABLED, which is done "right" in
+        // devel but requires functions not available in stable. RFC requires us to
+        // not send LOGIN when LOGINDISABLED is advertised.
+        if(stristr($server_info, 'LOGINDISABLED')) {
+            $response = 'BAD';
+            $message = _("The IMAP server is reporting that plain text logins are disabled.").' '.
+                _("Using CRAM-MD5 or DIGEST-MD5 authentication instead may work.").' ';
+            if (!$use_imap_tls) {
+                $message .= _("Also, the use of TLS may allow SquirrelMail to login.").' ';
+            }
+            $message .= _("Please contact your system administrator and report this error.");
+        } else {
+            // Original IMAP login code
+            $query = 'LOGIN';
+            if(sq_is8bit($username)) {
+                $query .= ' {' . strlen($username) . "}\r\n$username";
+            } else {
+                $query .= ' "' . quoteimap($username) . '"';
+            }
+            if(sq_is8bit($password)) {
+                $query .= ' {' . strlen($password) . "}\r\n$password";
+            } else {
+                $query .= ' "' . quoteimap($password) . '"';
+            }
+            $read = sqimap_run_command ($imap_stream, $query, false, $response, $message);
+        }
+    } elseif ($imap_auth_mech == 'plain') {
+        /* Replace this with SASL PLAIN if it ever gets implemented */
+        $response="BAD";
+        $message='SquirrelMail does not support SASL PLAIN yet. Rerun conf.pl and use login instead.';
+    } else {
+        $response="BAD";
+        $message="Internal SquirrelMail error - unknown IMAP authentication method chosen.  Please contact the developers.";
+    }
+
+    /* If the connection was not successful, lets see why */
     if ($response != 'OK') {
         if (!$hide) {
             if ($response != 'NO') {
@@ -522,14 +543,14 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
                 set_up_language($squirrelmail_language, true);
                 require_once(SM_PATH . 'functions/display_messages.php');
                 if ($response == 'BAD') {
-                    $string = sprintf (_("Bad request: %s")."<br>\r\n", $message);
+                    $string = sprintf (_("Bad request: %s")."<br />\r\n", $message);
                 } else {
-                    $string = sprintf (_("Unknown error: %s") . "<br>\n", $message);
+                    $string = sprintf (_("Unknown error: %s") . "<br />\n", $message);
                 }
                 if (isset($read) && is_array($read)) {
-                    $string .= '<br>' . _("Read data:") . "<br>\n";
+                    $string .= '<br />' . _("Read data:") . "<br />\n";
                     foreach ($read as $line) {
-                        $string .= htmlspecialchars($line) . "<br>\n";
+                        $string .= htmlspecialchars($line) . "<br />\n";
                     }
                 }
                 error_box($string,$color);
@@ -545,10 +566,12 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
                  * $squirrelmail_language is set by a cookie when
                  * the user selects language and logs out
                  */
-                
+
                 set_up_language($squirrelmail_language, true);
                 include_once(SM_PATH . 'functions/display_messages.php' );
                 sqsession_destroy();
+                /* terminate the session nicely */
+                sqimap_logout($imap_stream);
                 logout_error( _("Unknown user or password incorrect.") );
                 exit;
             }
@@ -559,14 +582,23 @@ function sqimap_login ($username, $password, $imap_server_address, $imap_port, $
     return $imap_stream;
 }
 
-/* Simply logs out the IMAP session */
+/**
+ * Simply logs out the IMAP session
+ * @param stream imap_stream the IMAP connection to log out.
+ * @return void
+ */
 function sqimap_logout ($imap_stream) {
     /* Logout is not valid until the server returns 'BYE'
-     * If we don't have an imap_ stream we're already logged out */
+     * If we don't have an imap_stream we're already logged out */
     if(isset($imap_stream) && $imap_stream)
         sqimap_run_command($imap_stream, 'LOGOUT', false, $response, $message);
 }
 
+/**
+ * Retreive the CAPABILITY string from the IMAP server.
+ * If capability is set, returns only that specific capability,
+ * else returns array of all capabilities.
+ */
 function sqimap_capability($imap_stream, $capability='') {
     global $sqimap_capabilities;
     if (!is_array($sqimap_capabilities)) {
@@ -576,6 +608,8 @@ function sqimap_capability($imap_stream, $capability='') {
         for ($i=2; $i < count($c); $i++) {
             $cap_list = explode('=', $c[$i]);
             if (isset($cap_list[1])) {
+                // FIX ME. capabilities can occure multiple times.
+                // THREAD=REFERENCES THREAD=ORDEREDSUBJECT
                 $sqimap_capabilities[$cap_list[0]] = $cap_list[1];
             } else {
                 $sqimap_capabilities[$cap_list[0]] = TRUE;
@@ -592,7 +626,9 @@ function sqimap_capability($imap_stream, $capability='') {
     return $sqimap_capabilities;
 }
 
-/* Returns the delimeter between mailboxes: INBOX/Test, or INBOX.Test */
+/**
+ * Returns the delimeter between mailboxes: INBOX/Test, or INBOX.Test
+ */
 function sqimap_get_delimiter ($imap_stream = false) {
     global $sqimap_delimiter, $optional_delimiter;
 
@@ -638,7 +674,9 @@ function sqimap_get_delimiter ($imap_stream = false) {
 }
 
 
-/* Gets the number of messages in the current mailbox. */
+/**
+ * Gets the number of messages in the current mailbox.
+ */
 function sqimap_get_num_messages ($imap_stream, $mailbox) {
     $read_ary = sqimap_run_command ($imap_stream, "EXAMINE \"$mailbox\"", false, $result, $message);
     for ($i = 0; $i < count($read_ary); $i++) {
@@ -649,7 +687,6 @@ function sqimap_get_num_messages ($imap_stream, $mailbox) {
     return false; //"BUG! Couldn't get number of messages in $mailbox!";
 }
 
-
 function parseAddress($address, $max=0) {
     $aTokens = array();
     $aAddress = array();
@@ -742,7 +779,7 @@ function parseAddress($address, $max=0) {
           case '=':
           case '"':
           case ' ':
-            $aStack[] = $sToken; 
+            $aStack[] = $sToken;
             break;
           case '(':
             $aComment[] = substr($sToken,1,-1);
@@ -763,7 +800,7 @@ function parseAddress($address, $max=0) {
             }
             if (count($aStack)) {
                 $sPersonal = trim(implode('',$aStack));
-            } else { 
+            } else {
                 $sPersonal = '';
             }
             if (!$sPersonal && count($aComment)) {
@@ -774,7 +811,7 @@ function parseAddress($address, $max=0) {
             $sPersonal = $sComment = $sEmail = '';
             $aStack = $aComment = array();
             break;
-          case ':': 
+          case ':':
             $sGroup = implode(' ',$aStack); break;
             $aStack = array();
             break;
@@ -783,7 +820,7 @@ function parseAddress($address, $max=0) {
             break;
           case '>':
             /* skip */
-            break; 
+            break;
           default: $aStack[] = $sToken; break;
         }
     }
@@ -804,12 +841,11 @@ function parseAddress($address, $max=0) {
     }
     $aAddress[] = array($sEmail,$sPersonal);
     return $aAddress;
-} 
+}
 
 
-
-/*
- * Returns the number of unseen messages in this folder
+/**
+ * Returns the number of unseen messages in this folder.
  */
 function sqimap_unseen_messages ($imap_stream, $mailbox) {
     $read_ary = sqimap_run_command ($imap_stream, "STATUS \"$mailbox\" (UNSEEN)", false, $result, $message);
@@ -824,7 +860,7 @@ function sqimap_unseen_messages ($imap_stream, $mailbox) {
     return $regs[1];
 }
 
-/*
+/**
  * Returns the number of unseen/total messages in this folder
  */
 function sqimap_status_messages ($imap_stream, $mailbox) {
@@ -841,48 +877,55 @@ function sqimap_status_messages ($imap_stream, $mailbox) {
         }
         if (preg_match('/RECENT\s+([0-9]+)/i', $read_ary[$i], $regs)) {
             $recent = $regs[1];
-        }        
+        }
         $i++;
     }
     return array('MESSAGES' => $messages, 'UNSEEN'=>$unseen, 'RECENT' => $recent);
 }
 
 
-/*
- *  Saves a message to a given folder -- used for saving sent messages
+/**
+ * Saves a message to a given folder -- used for saving sent messages
  */
 function sqimap_append ($imap_stream, $sent_folder, $length) {
     fputs ($imap_stream, sqimap_session_id() . " APPEND \"$sent_folder\" (\\Seen) \{$length}\r\n");
     $tmp = fgets ($imap_stream, 1024);
+    sqimap_append_checkresponse($tmp, $sent_folder);
 }
 
 function sqimap_append_done ($imap_stream, $folder='') {
-    global $squirrelmail_language, $color;
     fputs ($imap_stream, "\r\n");
     $tmp = fgets ($imap_stream, 1024);
-    if (preg_match("/(.*)(BAD|NO)(.*)$/", $tmp, $regs)) {
+    sqimap_append_checkresponse($tmp, $folder);
+}
+
+function sqimap_append_checkresponse($response, $folder) {
+
+    if (preg_match("/(.*)(BAD|NO)(.*)$/", $response, $regs)) {
+        global $squirrelmail_language, $color;
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
+
         $reason = $regs[3];
         if ($regs[2] == 'NO') {
-           $string = "<b><font color=$color[2]>\n" .
-                  _("ERROR : Could not append message to") ." $folder." .
-                  "</b><br>\n" .
-                  _("Server responded: ") .
-                  $reason . "<br>\n";
+           $string = "<b><font color=\"$color[2]\">\n" .
+                  _("ERROR: Could not append message to") ." $folder." .
+                  "</b><br />\n" .
+                  _("Server responded:") . ' ' .
+                  $reason . "<br />\n";
            if (preg_match("/(.*)(quota)(.*)$/i", $reason, $regs)) {
-              $string .= _("Solution: ") . 
-            _("Remove unneccessary messages from your folder and start with your Trash folder.") 
-              ."<br>\n";
+              $string .= _("Solution:") . ' ' .
+            _("Remove unneccessary messages from your folder and start with your Trash folder.")
+              ."<br />\n";
            }
            $string .= "</font>\n";
            error_box($string,$color);
         } else {
-           $string = "<b><font color=$color[2]>\n" .
-                  _("ERROR : Bad or malformed request.") .
-                  "</b><br>\n" .
-                  _("Server responded: ") .
-                  $tmp . "</font><br>\n";
+           $string = "<b><font color=\"$color[2]\">\n" .
+                  _("ERROR: Bad or malformed request.") .
+                  "</b><br />\n" .
+                  _("Server responded:") . ' ' .
+                  $reason . "</font><br />\n";
            error_box($string,$color);
            exit;
         }
@@ -897,14 +940,15 @@ function sqimap_get_user_server ($imap_server, $username) {
    return $function($username);
 }
 
-/* This is an example that gets imapservers from yellowpages (NIS).
- * you can simple put map:map_yp_alias in your $imap_server_address 
+/**
+ * This is an example that gets IMAP servers from yellowpages (NIS).
+ * you can simple put map:map_yp_alias in your $imap_server_address
  * in config.php use your own function instead map_yp_alias to map your
- * LDAP whatever way to find the users imapserver. */
-
+ * LDAP whatever way to find the users IMAP server.
+ */
 function map_yp_alias($username) {
    $yp = `ypmatch $username aliases`;
    return chop(substr($yp, strlen($username)+1));
-} 
+}
 
 ?>
