@@ -3,43 +3,33 @@
 /**
  * imap_messages.php
  *
- * Copyright (c) 1999-2004 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This implements functions that manipulate messages
+ * NOTE: Quite a few functions in this file are obsolete
  *
- * $Id: imap_messages.php,v 1.134.2.13 2004/04/20 16:55:41 stekkel Exp $
+ * @version $Id: imap_messages.php,v 1.134.2.19 2005/04/16 17:45:38 jervfors Exp $
+ * @package squirrelmail
+ * @subpackage imap
  */
 
-/* NOTE: quite some functions in this file are not used anymore. */
 
-/* Copies specified messages to specified folder */
-/* obsolete */
-function sqimap_messages_copy ($imap_stream, $start, $end, $mailbox) {
+/**
+ * Copy a set of messages ($id) to another mailbox ($mailbox)
+ */
+function sqimap_msgs_list_copy($imap_stream, $id, $mailbox) {
     global $uid_support;
-    $read = sqimap_run_command ($imap_stream, "COPY $start:$end \"$mailbox\"", true, $response, $message, $uid_support);
-}
-
-function sqimap_msgs_list_copy ($imap_stream, $id, $mailbox) {
-    global $uid_support;
-    $msgs_id = sqimap_message_list_squisher($id);    
+    $msgs_id = sqimap_message_list_squisher($id);
     $read = sqimap_run_command ($imap_stream, "COPY $msgs_id \"$mailbox\"", true, $response, $message, $uid_support);
     $read = sqimap_run_command ($imap_stream, "STORE $msgs_id +FLAGS (\\Deleted)", true, $response, $message, $uid_support);
 }
 
 
-/* Deletes specified messages and moves them to trash if possible */
-/* obsolete */
-function sqimap_messages_delete ($imap_stream, $start, $end, $mailbox) {
-    global $move_to_trash, $trash_folder, $auto_expunge, $uid_support;
-
-    if (($move_to_trash == true) && (sqimap_mailbox_exists($imap_stream, $trash_folder) && ($mailbox != $trash_folder))) {
-        sqimap_messages_copy ($imap_stream, $start, $end, $trash_folder);
-    }
-    sqimap_messages_flag ($imap_stream, $start, $end, "Deleted", true);
-}
-
-function sqimap_msgs_list_delete ($imap_stream, $mailbox, $id) {
+/**
+ * Deletes a message and move it to trash or expunge the mailbox
+ */
+function sqimap_msgs_list_delete($imap_stream, $mailbox, $id) {
     global $move_to_trash, $trash_folder, $uid_support;
     $msgs_id = sqimap_message_list_squisher($id);
     if (($move_to_trash == true) && (sqimap_mailbox_exists($imap_stream, $trash_folder) && ($mailbox != $trash_folder))) {
@@ -49,32 +39,7 @@ function sqimap_msgs_list_delete ($imap_stream, $mailbox, $id) {
 }
 
 
-/* Sets the specified messages with specified flag */
-function sqimap_messages_flag ($imap_stream, $start, $end, $flag, $handle_errors) {
-    global $uid_support;
-    $read = sqimap_run_command ($imap_stream, "STORE $start:$end +FLAGS (\\$flag)", $handle_errors, $response, $message, $uid_support);
-}
-
-/* Remove specified flag from specified messages */
-function sqimap_messages_remove_flag ($imap_stream, $start, $end, $flag, $handle_errors) {
-    global $uid_support;
-    $read = sqimap_run_command ($imap_stream, "STORE $start:$end -FLAGS (\\$flag)", $handle_errors, $response, $message, $uid_support);
-}
-
-function sqimap_toggle_flag($imap_stream, $id, $flag, $set, $handle_errors) {
-    global $uid_support;
-    $msgs_id = sqimap_message_list_squisher($id);
-    $set_string = ($set ? '+' : '-');
-    $read = sqimap_run_command ($imap_stream, "STORE $msgs_id ".$set_string."FLAGS ($flag)", $handle_errors, $response, $message, $uid_support);
-}
-
-// obsolete?
-function sqimap_get_small_header ($imap_stream, $id, $sent) {
-    $res = sqimap_get_small_header_list($imap_stream, $id, $sent);
-    return $res[0];
-}
-
-/*
+/**
  * Sort the message list and crunch to be as small as possible
  * (overflow could happen, so make it small if possible)
  */
@@ -102,8 +67,11 @@ function sqimap_message_list_squisher($messages_array) {
     return $msgs_str;
 }
 
-/* returns the references header lines */
-function get_reference_header ($imap_stream, $message) {
+
+/**
+ * Returns the references header lines
+ */
+function get_reference_header($imap_stream, $message) {
     global $uid_support;
     $responses = array ();
     $results = array();
@@ -111,17 +79,15 @@ function get_reference_header ($imap_stream, $message) {
     $responses = sqimap_run_command_list ($imap_stream, "FETCH $message BODY[HEADER.FIELDS (References)]", true, $response, $message, $uid_support);
     if (!eregi("^\\* ([0-9]+) FETCH", $responses[0][0], $regs)) {
         $responses = array ();
-    } 
+    }
     return $responses;
 }
 
 
-/* get sort order from server and
- * return it as the $id array for
- * mailbox_display
+/**
+ * Get sort order from server and return it as the $id array for mailbox_display
  */
-
-function sqimap_get_sort_order ($imap_stream, $sort, $mbxresponse) {
+function sqimap_get_sort_order($imap_stream, $sort, $mbxresponse) {
     global  $default_charset, $thread_sort_messages,
             $internal_date_sort, $server_sort_array,
             $sent_folder, $mailbox, $uid_support;
@@ -207,7 +173,7 @@ function sqimap_get_sort_order ($imap_stream, $sort, $mbxresponse) {
  * @param  array    $mbxresponse response from a sqimap_mailbox_select
  * @return array    $php_sort_array
  */
-function sqimap_get_php_sort_order ($imap_stream, $mbxresponse) {
+function sqimap_get_php_sort_order($imap_stream, $mbxresponse) {
     global $uid_support;
 
     if (sqsession_is_registered('php_sort_array')) {
@@ -245,12 +211,12 @@ function sqimap_get_php_sort_order ($imap_stream, $mbxresponse) {
 }
 
 
-/* returns an indent array for printMessageinfo()
-   this represents the amount of indent needed (value)
-   for this message number (key)
-*/
-
-function get_parent_level ($imap_stream) {
+/**
+ * Returns an indent array for printMessageinfo()
+ * This represents the amount of indent needed (value),
+ * for this message number (key)
+ */
+function get_parent_level($imap_stream) {
     global $sort_by_ref, $default_charset, $thread_new;
         $parent = "";
         $child = "";
@@ -263,15 +229,15 @@ function get_parent_level ($imap_stream) {
         $thread_new[$i] = preg_replace("/\s\(/", "(", $thread_new[$i]);
         $thread_new[$i] = preg_replace("/(\d+)/", "$1|", $thread_new[$i]);
         $thread_new[$i] = preg_split("/\|/", $thread_new[$i], -1, PREG_SPLIT_NO_EMPTY);
-    } 
+    }
     $indent_array = array();
-        if (!$thread_new) {
-            $thread_new = array();
-        }
+    if (!$thread_new) {
+        $thread_new = array();
+    }
     /* looping through the parts of one message thread */
 
     for ($i=0;$i<count($thread_new);$i++) {
-    /* first grab the parent, it does not indent */
+        /* first grab the parent, it does not indent */
 
         if (isset($thread_new[$i][0])) {
             if (preg_match("/(\d+)/", $thread_new[$i][0], $regs)) {
@@ -280,10 +246,11 @@ function get_parent_level ($imap_stream) {
         }
         $indent_array[$parent] = 0;
 
-    /* now the children, checking each thread portion for
-       ),(, and space, adjusting the level and space values
-       to get the indent level
-    */
+        /*
+         * now the children, checking each thread portion for
+         * ),(, and space, adjusting the level and space values
+         * to get the indent level
+         */
         $level = 0;
         $spaces = array();
         $spaces_total = 0;
@@ -292,14 +259,14 @@ function get_parent_level ($imap_stream) {
         for ($k=1;$k<(count($thread_new[$i]))-1;$k++) {
             $chars = count_chars($thread_new[$i][$k], 1);
             if (isset($chars['40'])) {       /* testing for ( */
-                $level = $level + $chars['40'];
+                $level += $chars['40'];
             }
             if (isset($chars['41'])) {      /* testing for ) */
-                $level = $level - $chars['41'];
+                $level -= $chars['41'];
                 $spaces[$level] = 0;
                 /* if we were faking lets stop, this portion
-                   of the thread is over
-                */
+                 * of the thread is over
+                 */
                 if ($level == $cutoff) {
                     $fake = FALSE;
                 }
@@ -308,17 +275,17 @@ function get_parent_level ($imap_stream) {
                 if (!isset($spaces[$level])) {
                     $spaces[$level] = 0;
                 }
-                $spaces[$level] = $spaces[$level] + $chars['32'];
+                $spaces[$level] += $chars['32'];
             }
             for ($x=0;$x<=$level;$x++) {
                 if (isset($spaces[$x])) {
-                    $spaces_total = $spaces_total + $spaces[$x];
+                    $spaces_total += $spaces[$x];
                 }
             }
             $indent = $level + $spaces_total;
             /* must have run into a message that broke the thread
-               so we are adjusting for that portion
-            */
+             * so we are adjusting for that portion
+             */
             if ($fake == TRUE) {
                 $indent = $indent +1;
             }
@@ -326,16 +293,16 @@ function get_parent_level ($imap_stream) {
                 $child = $regs[1];
             }
             /* the thread must be broken if $indent == 0
-               so indent the message once and start faking it
-            */
+             * so indent the message once and start faking it
+             */
             if ($indent == 0) {
                 $indent = 1;
                 $fake = TRUE;
                 $cutoff = $level;
             }
             /* dont need abs but if indent was negative
-               errors would occur
-            */
+             * errors would occur
+             */
             $indent_array[$child] = abs($indent);
             $spaces_total = 0;
         }
@@ -344,12 +311,11 @@ function get_parent_level ($imap_stream) {
 }
 
 
-/* returns an array with each element as a string
-   representing one message thread as returned by
-   the IMAP server
-*/
-
-function get_thread_sort ($imap_stream) {
+/**
+ * Returns an array with each element as a string representing one
+ * message-thread as returned by the IMAP server.
+ */
+function get_thread_sort($imap_stream) {
     global $thread_new, $sort_by_ref, $default_charset, $server_sort_array, $uid_support;
     if (sqsession_is_registered('thread_new')) {
         sqsession_unregister('thread_new');
@@ -360,56 +326,54 @@ function get_thread_sort ($imap_stream) {
     $thread_temp = array ();
     if ($sort_by_ref == 1) {
         $sort_type = 'REFERENCES';
-    }
-    else {
+    } else {
         $sort_type = 'ORDEREDSUBJECT';
     }
     $query = "THREAD $sort_type ".strtoupper($default_charset)." ALL";
+
     $thread_test = sqimap_run_command ($imap_stream, $query, true, $response, $message, $uid_support);
     if (isset($thread_test[0])) {
-       for ($i=0,$iCnt=count($thread_test);$i<$iCnt;++$i) {
-           if (preg_match("/^\* THREAD (.+)$/", $thread_test[$i], $regs)) {
-              $thread_list = trim($regs[1]);
-	      break;
-           }
-       } 	
-    }
-    else {
-       $thread_list = "";
+        for ($i=0,$iCnt=count($thread_test);$i<$iCnt;++$i) {
+            if (preg_match("/^\* THREAD (.+)$/", $thread_test[$i], $regs)) {
+                $thread_list = trim($regs[1]);
+                break;
+            }
+        }
+    } else {
+        $thread_list = "";
     }
     if (!preg_match("/OK/", $response)) {
-       $server_sort_array = 'no';
-       return $server_sort_array;
+        $server_sort_array = 'no';
+        return $server_sort_array;
     }
     if (isset($thread_list)) {
         $thread_temp = preg_split("//", $thread_list, -1, PREG_SPLIT_NO_EMPTY);
     }
+
     $char_count = count($thread_temp);
     $counter = 0;
     $thread_new = array();
     $k = 0;
     $thread_new[0] = "";
     for ($i=0;$i<$char_count;$i++) {
-            if ($thread_temp[$i] != ')' && $thread_temp[$i] != '(') {
-                    $thread_new[$k] = $thread_new[$k] . $thread_temp[$i];
-            }
-            elseif ($thread_temp[$i] == '(') {
-                    $thread_new[$k] .= $thread_temp[$i];
-                    $counter++;
-            }
-            elseif ($thread_temp[$i] == ')') {
-                    if ($counter > 1) {
-                            $thread_new[$k] .= $thread_temp[$i];
-                            $counter = $counter - 1;
-                    }
-                    else {
-                            $thread_new[$k] .= $thread_temp[$i];
-                            $k++;
-                            $thread_new[$k] = "";
-                            $counter = $counter - 1;
-                    }
+        if ($thread_temp[$i] != ')' && $thread_temp[$i] != '(') {
+            $thread_new[$k] = $thread_new[$k] . $thread_temp[$i];
+        } elseif ($thread_temp[$i] == '(') {
+            $thread_new[$k] .= $thread_temp[$i];
+            $counter++;
+        } elseif ($thread_temp[$i] == ')') {
+            if ($counter > 1) {
+                $thread_new[$k] .= $thread_temp[$i];
+                $counter = $counter - 1;
+            } else {
+                $thread_new[$k] .= $thread_temp[$i];
+                $k++;
+                $thread_new[$k] = "";
+                $counter = $counter - 1;
             }
+        }
     }
+
     sqsession_register($thread_new, 'thread_new');
     $thread_new = array_reverse($thread_new);
     $thread_list = implode(" ", $thread_new);
@@ -417,61 +381,77 @@ function get_thread_sort ($imap_stream) {
     $thread_list = str_replace(")", " ", $thread_list);
     $thread_list = preg_split("/\s/", $thread_list, -1, PREG_SPLIT_NO_EMPTY);
     $server_sort_array = $thread_list;
+
     sqsession_register($server_sort_array, 'server_sort_array');
     return $thread_list;
 }
 
 
 function elapsedTime($start) {
- $stop = gettimeofday();
- $timepassed =  1000000 * ($stop['sec'] - $start['sec']) + $stop['usec'] - $start['usec'];
- return $timepassed;
+    $stop = gettimeofday();
+    $timepassed =  1000000 * ($stop['sec'] - $start['sec']) + $stop['usec'] - $start['usec'];
+    return $timepassed;
 }
 
-// only used in sqimap_get_small_header_list
+
+/**
+ * Parses a string in an imap response. String starts with " or { which means it
+ * can handle double quoted strings and literal strings
+ *
+ * @param string $read imap response
+ * @param integer $i (reference) offset in string
+ * @return string $s parsed string without the double quotes or literal count
+ */
 function parseString($read,&$i) {
     $char = $read{$i};
     $s = '';
     if ($char == '"') {
-       $iPos = ++$i;
-       while (true) {
-          $iPos = strpos($read,'"',$iPos);
-          if (!$iPos) break;
-             if ($iPos && $read{$iPos -1} != '\\') {
+        $iPos = ++$i;
+        while (true) {
+            $iPos = strpos($read,'"',$iPos);
+            if (!$iPos) break;
+            if ($iPos && $read{$iPos -1} != '\\') {
                 $s = substr($read,$i,($iPos-$i));
                 $i = $iPos;
                 break;
-             }
-             $iPos++;
-             if ($iPos > strlen($read)) {
+            }
+            $iPos++;
+            if ($iPos > strlen($read)) {
                 break;
-             }
-       }
+            }
+        }
     } else if ($char == '{') {
         $lit_cnt = '';
         ++$i;
         $iPos = strpos($read,'}',$i);
         if ($iPos) {
-           $lit_cnt = substr($read, $i, $iPos - $i);
-           $i += strlen($lit_cnt) + 3; /* skip } + \r + \n */
-           /* Now read the literal */
-           $s = ($lit_cnt ? substr($read,$i,$lit_cnt): '');
-           $i += $lit_cnt;
-           /* temp bugfix (SM 1.5 will have a working clean version)
-              too much work to implement that version right now */
-           --$i;
-         } else { /* should never happen */
+            $lit_cnt = substr($read, $i, $iPos - $i);
+            $i += strlen($lit_cnt) + 3; /* skip } + \r + \n */
+            /* Now read the literal */
+            $s = ($lit_cnt ? substr($read,$i,$lit_cnt): '');
+            $i += $lit_cnt;
+            /* temp bugfix (SM 1.5 will have a working clean version)
+               too much work to implement that version right now */
+            --$i;
+        } else { /* should never happen */
             $i += 3; /* } + \r + \n */
             $s = '';
-         }
+        }
     } else {
-       return false;
+        return false;
     }
     ++$i;
     return $s;
 }
 
-// only used in sqimap_get_small_header_list
+
+/**
+ * Parses a string containing an array from an imap response. String starts with ( and end with )
+ *
+ * @param string $read imap response
+ * @param integer $i (reference) offset in string
+ * @return array $a
+ */
 function parseArray($read,&$i) {
     $i = strpos($read,'(',$i);
     $i_pos = strpos($read,')',$i);
@@ -485,14 +465,42 @@ function parseArray($read,&$i) {
     }
 }
 
-function sqimap_get_small_header_list ($imap_stream, $msg_list, $show_num=false) {
+/**
+ * Normalise the different Priority headers into a uniform value,
+ * namely that of the X-Priority header (1, 3, 5). Supports:
+ * Prioirty, X-Priority, Importance.
+ * X-MS-Mail-Priority is not parsed because it always coincides
+ * with one of the other headers.
+ *
+ * DUPLICATE CODE ALERT:
+ * NOTE: this is actually a duplicate from the function in
+ * class/mime/Rfc822Header.php.
+ */
+function parsePriority($value) {
+    $value = strtolower(array_shift(split('/\w/',trim($value))));
+    if ( is_numeric($value) ) {
+        return $value;
+    }
+    if ( $value == 'urgent' || $value == 'high' ) {
+        return 1;
+    } elseif ( $value == 'non-urgent' || $value == 'low' ) {
+        return 5;
+    }
+    return 3;
+}
+
+
+/**
+ * Retrieves a list with headers, flags, size or internaldate from the imap server
+ */
+function sqimap_get_small_header_list($imap_stream, $msg_list, $show_num=false) {
     global $squirrelmail_language, $color, $data_dir, $username, $imap_server_type;
     global $uid_support, $allow_server_sort;
     /* Get the small headers for each message in $msg_list */
     $maxmsg = sizeof($msg_list);
     if ($show_num != '999999') {
         $msgs_str = sqimap_message_list_squisher($msg_list);
-    } else { 
+    } else {
         $msgs_str = '1:*';
     }
     $messages = array();
@@ -509,13 +517,13 @@ function sqimap_get_small_header_list ($imap_stream, $msg_list, $show_num=false)
 
     $internaldate = getPref($data_dir, $username, 'internal_date_sort');
     if ($internaldate) {
-        $query = "FETCH $msgs_str (FLAGS UID RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER.FIELDS (Date To Cc From Subject X-Priority Content-Type)])";
+        $query = "FETCH $msgs_str (FLAGS UID RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER.FIELDS (Date To Cc From Subject X-Priority Importance Priority Content-Type)])";
     } else {
-        $query = "FETCH $msgs_str (FLAGS UID RFC822.SIZE BODY.PEEK[HEADER.FIELDS (Date To Cc From Subject X-Priority Content-Type)])";
+        $query = "FETCH $msgs_str (FLAGS UID RFC822.SIZE BODY.PEEK[HEADER.FIELDS (Date To Cc From Subject X-Priority Importance Priority Content-Type)])";
     }
     $read_list = sqimap_run_command_list ($imap_stream, $query, true, $response, $message, $uid_support);
     $i = 0;
-    
+
     foreach ($read_list as $r) {
         /* initialize/reset vars */
         $subject = _("(no subject)");
@@ -526,26 +534,26 @@ function sqimap_get_small_header_list ($imap_stream, $msg_list, $show_num=false)
         $cc = $to = $inrepto = '';
         // use unset because we do isset below
         unset($date);
-	
+
         $flag_seen = $flag_answered = $flag_deleted = $flag_flagged = false;
 
         $read = implode('',$r);
 
-        /* 
-            * #id<space>FETCH<space>(
-        */
-    
+        /*
+         * #id<space>FETCH<space>(
+         */
+
         /* extract the message id */
         $i_space = strpos($read,' ',2);
         $id = substr($read,2,$i_space-2);
         $fetch = substr($read,$i_space+1,5);
         if (!is_numeric($id) && $fetch !== 'FETCH') {
             set_up_language($squirrelmail_language);
-            echo '<br><b><font color=$color[2]>' .
-                 _("ERROR : Could not complete request.") .
-                 '</b><br>' .
-                 _("Unknown response from IMAP server: ") . ' 1.' .
-                 htmlspecialchars($read) . "</font><br>\n";
+            echo '<br /><b><font color="'.$color[2].'">' .
+                 _("ERROR: Could not complete request.") .
+                 '</b><br />' .
+                 _("Unknown response from IMAP server:") . ' 1.' .
+                 htmlspecialchars($read) . "</font><br />\n";
                  break;
         }
         $i = strpos($read,'(',$i_space+5);
@@ -599,14 +607,14 @@ function sqimap_get_small_header_list ($imap_stream, $msg_list, $show_num=false)
                 } else {
                     break 3;
                 }
-                
+
                 break;
             case 'INTERNALDATE':
                 $date = parseString($read,$i);
                 //if ($tmpdate === false) break 3;
                 //$tmpdate = str_replace('  ',' ',$tmpdate);
                 //$tmpdate = explode(' ',$tmpdate);
-                //$date = str_replace('-',' ',$tmpdate[0]) . " " . 
+                //$date = str_replace('-',' ',$tmpdate[0]) . " " .
                 //                            $tmpdate[1] . ' ' . $tmpdate[2];
                 break;
             case 'BODY.PEEK[HEADER.FIELDS':
@@ -631,7 +639,10 @@ function sqimap_get_small_header_list ($imap_stream, $msg_list, $show_num=false)
                             case 'cc': $cc = $value; break;
                             case 'from': $from = $value; break;
                             case 'date': $date = $value; break;
-                            case 'x-priority': $priority = $value; break;
+                            case 'x-priority':
+                            case 'importance':
+                            case 'priority':
+                                $priority = parsePriority($value); break;
                             case 'subject':
                                 $subject = $value;
                                 if ($subject == "") {
@@ -714,9 +725,12 @@ function sqimap_get_small_header_list ($imap_stream, $msg_list, $show_num=false)
     return $new_messages;
 }
 
-// obsolete?
+
+/**
+ * Obsolete?
+ */
 function sqimap_get_headerfield($imap_stream, $field) {
-    global $uid_support;
+    global $uid_support, $squirrelmail_language;
     $sid = sqimap_session_id(false);
 
     $results = array();
@@ -730,30 +744,30 @@ function sqimap_get_headerfield($imap_stream, $field) {
         $r = implode('',$r);
         /* first we unfold the header */
         $r = str_replace(array("\r\n", "\n\t","\n\s"),array("\n",'',''),$r);
-        /* 
-         * now we can make a new header array with each element representing 
+        /*
+         * now we can make a new header array with each element representing
          * a headerline
          */
-        $r = explode("\n" , $r);  
+        $r = explode("\n" , $r);
         if (!$uid_support) {
             if (!preg_match("/^\\*\s+([0-9]+)\s+FETCH/iAU",$r[0], $regs)) {
                 set_up_language($squirrelmail_language);
-                echo '<br><b><font color=$color[2]>' .
-                      _("ERROR : Could not complete request.") .
-                      '</b><br>' .
-                      _("Unknown response from IMAP server: ") . ' 1.' .
-                      $r[0] . "</font><br>\n";
+                echo '<br /><b><font color="'.$color[2].'">' .
+                      _("ERROR: Could not complete request.") .
+                      '</b><br />' .
+                      _("Unknown response from IMAP server:") . ' 1.' .
+                      $r[0] . "</font><br />\n";
             } else {
                 $id = $regs[1];
             }
         } else {
             if (!preg_match("/^\\*\s+([0-9]+)\s+FETCH.*UID\s+([0-9]+)\s+/iAU",$r[0], $regs)) {
                 set_up_language($squirrelmail_language);
-                echo '<br><b><font color=$color[2]>' .
-                     _("ERROR : Could not complete request.") .
-                     '</b><br>' .
-                     _("Unknown response from IMAP server: ") . ' 1.' .
-                     $r[0] . "</font><br>\n";
+                echo '<br /><b><font color="'.$color[2].'">' .
+                     _("ERROR: Could not complete request.") .
+                     '</b><br />' .
+                     _("Unknown response from IMAP server:") . ' 1.' .
+                     $r[0] . "</font><br />\n";
             } else {
                 $id = $regs[2];
             }
@@ -766,21 +780,17 @@ function sqimap_get_headerfield($imap_stream, $field) {
 }
 
 
-
-
- 
-/*
- * Returns a message array with all the information about a message.  
+/**
+ * Returns a message array with all the information about a message.
  * See the documentation folder for more information about this array.
  */
-function sqimap_get_message ($imap_stream, $id, $mailbox) {
+function sqimap_get_message($imap_stream, $id, $mailbox) {
     global $uid_support;
 
-    // prohibit 1:* msgs sets
+    // typecast to int to prohibit 1:* msgs sets
     $id = (int) $id;
-
     $flags = array();
-    $read = sqimap_run_command ($imap_stream, "FETCH $id (FLAGS BODYSTRUCTURE)", true, $response, $message, $uid_support);
+    $read = sqimap_run_command($imap_stream, "FETCH $id (FLAGS BODYSTRUCTURE)", true, $response, $message, $uid_support);
     if ($read) {
         if (preg_match('/.+FLAGS\s\((.*)\)\s/AUi',$read[0],$regs)) {
             if (trim($regs[1])) {
@@ -792,51 +802,117 @@ function sqimap_get_message ($imap_stream, $id, $mailbox) {
         global $sort, $startMessage, $color;
 
         $errmessage = _("The server couldn't find the message you requested.") .
-              '<p>'._("Most probably your message list was out of date and the message has been moved away or deleted (perhaps by another program accessing the same mailbox).");
+            '<p>'._("Most probably your message list was out of date and the message has been moved away or deleted (perhaps by another program accessing the same mailbox).");
         /* this will include a link back to the message list */
         error_message($errmessage, $mailbox, $sort, (int) $startMessage, $color);
         exit;
-    } 
+    }
     $bodystructure = implode('',$read);
     $msg =  mime_structure($bodystructure,$flags);
-    $read = sqimap_run_command ($imap_stream, "FETCH $id BODY[HEADER]", true, $response, $message, $uid_support);
+    $read = sqimap_run_command($imap_stream, "FETCH $id BODY[HEADER]", true, $response, $message, $uid_support);
     $rfc822_header = new Rfc822Header();
     $rfc822_header->parseHeader($read);
     $msg->rfc822_header = $rfc822_header;
     return $msg;
 }
 
-/* Wrapper function that reformats the header information. */
-// obsolete?
-function sqimap_get_message_header ($imap_stream, $id, $mailbox) {
+
+/**
+ * Wrapper function that reformats the header information.
+ * Obsolete?
+ */
+function sqimap_get_message_header($imap_stream, $id, $mailbox) {
     global $uid_support;
     $read = sqimap_run_command ($imap_stream, "FETCH $id BODY[HEADER]", true, $response, $message, $uid_support);
-    $header = sqimap_get_header($imap_stream, $read); 
+    $header = sqimap_get_header($imap_stream, $read);
     $header->id = $id;
     $header->mailbox = $mailbox;
     return $header;
 }
 
-/* Wrapper function that reformats the entity header information. */
-// obsolete?
-function sqimap_get_ent_header ($imap_stream, $id, $mailbox, $ent) {
+
+/**
+ * Wrapper function that reformats the entity header information.
+ * Obsolete?
+ */
+function sqimap_get_ent_header($imap_stream, $id, $mailbox, $ent) {
     global $uid_support;
     $read = sqimap_run_command ($imap_stream, "FETCH $id BODY[$ent.HEADER]", true, $response, $message, $uid_support);
-    $header = sqimap_get_header($imap_stream, $read); 
+    $header = sqimap_get_header($imap_stream, $read);
     $header->id = $id;
     $header->mailbox = $mailbox;
     return $header;
 }
 
-/* function to get the mime headers */
-// obsolete?
-function sqimap_get_mime_ent_header ($imap_stream, $id, $mailbox, $ent) {
+
+/**
+ * Function to get the mime headers
+ * Obsolete?
+ */
+function sqimap_get_mime_ent_header($imap_stream, $id, $mailbox, $ent) {
     global $uid_support;
     $read = sqimap_run_command ($imap_stream, "FETCH $id:$id BODY[$ent.MIME]", true, $response, $message, $uid_support);
-    $header = sqimap_get_header($imap_stream, $read); 
+    $header = sqimap_get_header($imap_stream, $read);
     $header->id = $id;
     $header->mailbox = $mailbox;
     return $header;
 }
 
-?>
+
+/**
+ * Copies specified messages to specified folder
+ * Obsolete
+ */
+function sqimap_messages_copy($imap_stream, $start, $end, $mailbox) {
+    global $uid_support;
+    $read = sqimap_run_command ($imap_stream, "COPY $start:$end \"$mailbox\"", true, $response, $message, $uid_support);
+}
+
+
+/**
+ * Deletes specified messages and moves them to trash if possible
+ * Obsolete
+ */
+function sqimap_messages_delete($imap_stream, $start, $end, $mailbox) {
+    global $move_to_trash, $trash_folder, $auto_expunge, $uid_support;
+
+    if (($move_to_trash == true) && (sqimap_mailbox_exists($imap_stream, $trash_folder) && ($mailbox != $trash_folder))) {
+        sqimap_messages_copy ($imap_stream, $start, $end, $trash_folder);
+    }
+    sqimap_messages_flag ($imap_stream, $start, $end, "Deleted", true);
+}
+
+
+/**
+ * Sets the specified messages with specified flag
+ */
+function sqimap_messages_flag($imap_stream, $start, $end, $flag, $handle_errors) {
+    global $uid_support;
+    $read = sqimap_run_command ($imap_stream, "STORE $start:$end +FLAGS (\\$flag)", $handle_errors, $response, $message, $uid_support);
+}
+
+
+/* Remove specified flag from specified messages */
+function sqimap_messages_remove_flag($imap_stream, $start, $end, $flag, $handle_errors) {
+    global $uid_support;
+    $read = sqimap_run_command ($imap_stream, "STORE $start:$end -FLAGS (\\$flag)", $handle_errors, $response, $message, $uid_support);
+}
+
+
+function sqimap_toggle_flag($imap_stream, $id, $flag, $set, $handle_errors) {
+    global $uid_support;
+    $msgs_id = sqimap_message_list_squisher($id);
+    $set_string = ($set ? '+' : '-');
+    $read = sqimap_run_command ($imap_stream, "STORE $msgs_id ".$set_string."FLAGS ($flag)", $handle_errors, $response, $message, $uid_support);
+}
+
+
+/**
+ * Obsolete?
+ */
+function sqimap_get_small_header($imap_stream, $id, $sent) {
+    $res = sqimap_get_small_header_list($imap_stream, $id, $sent);
+    return $res[0];
+}
+
+?>
\ No newline at end of file
