@@ -3,15 +3,17 @@
 /**
  * mailbox_display.php
  *
- * Copyright (c) 1999-2004 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * $Id: mailbox_display.php,v 1.321.2.20 2004/04/19 16:21:53 jangliss Exp $
+ * @version $Id: mailbox_display.php,v 1.321.2.26 2005/04/09 17:41:06 jangliss Exp $
+ * @package squirrelmail
  */
 
+/** The standard includes.. */
 require_once(SM_PATH . 'functions/strings.php');
 require_once(SM_PATH . 'functions/html.php');
 require_once(SM_PATH . 'class/html.class.php');
@@ -41,7 +43,7 @@ function elapsed($start)
 function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                           $start_msg, $where, $what) {
     global $checkall,
-           $color, $msgs, $msort, $td_str, $msg, 
+           $color, $msgs, $msort, $td_str, $msg,
            $default_use_priority,
            $message_highlight_list,
            $index_order,
@@ -78,7 +80,8 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
        $msg['FROM'] = $msg['TO'];
     }
     $msg['FROM'] = parseAddress($msg['FROM'],1);
-    
+
+
        /*
         * This is done in case you're looking into Sent folders,
         * because you can have multiple receivers.
@@ -86,16 +89,26 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
 
     $senderNames = $msg['FROM'];
     $senderName  = '';
+    $senderFrom = '';
+
+
     if (sizeof($senderNames)){
         foreach ($senderNames as $senderNames_part) {
             if ($senderName != '') {
                 $senderName .= ', ';
             }
+
+            if ($senderFrom != '') {
+                $senderFrom .= ', ';
+            }
+
             if ($senderNames_part[1]) {
                 $senderName .= decodeHeader($senderNames_part[1]);
             } else {
                 $senderName .= htmlspecialchars($senderNames_part[0]);
             }
+
+            $senderFrom .= htmlspecialchars($senderNames_part[0]);
         }
     }
     $senderName = str_replace('&nbsp;',' ',$senderName);
@@ -135,7 +148,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     } else {
         $searchstr = '';
     }
-    
+
     if (is_array($message_highlight_list) && count($message_highlight_list)) {
         $msg['TO'] = parseAddress($msg['TO']);
         $msg['CC'] = parseAddress($msg['CC']);
@@ -167,7 +180,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                             $headertest = strtolower(decodeHeader($msg[$match_type], true, false));
                             if (strstr('^^' . $headertest, $high_val)) {
                                 $hlt_color = $message_highlight_list_part['color'];
-                                break 3; 
+                                break 3;
                             }
                             break;
                     }
@@ -183,7 +196,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     $col = 0;
     $msg['SUBJECT'] = decodeHeader($msg['SUBJECT']);
     $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
-    $subject = str_replace('&nbsp;',' ',$subject);    
+    $subject = str_replace('&nbsp;',' ',$subject);
     if (sizeof($index_order)) {
         foreach ($index_order as $index_order_part) {
             switch ($index_order_part) {
@@ -194,11 +207,13 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                                $hlt_color );
                 break;
             case 2: /* from */
+                $from_xtra = '';
+                $from_xtra = 'title="' . $senderFrom . '"';
                 echo html_tag( 'td',
                                $italic . $bold . $flag . $fontstr . $senderName .
                                $fontstr_end . $flag_end . $bold_end . $italic_end,
                                'left',
-                               $hlt_color );
+                               $hlt_color, $from_xtra );
                 break;
             case 3: /* date */
                 $date_string = $msg['DATE_STRING'] . '';
@@ -432,8 +447,9 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
                 $msgs = getServerMessages($imapConnection, $start_msg, $show_num, $num_msgs, $id);
                 if ($msgs === false) {
                     echo '<b><small><center><font color=red>' .
-                         _("Thread sorting is not supported by your IMAP server.<br>Please report this to the system administrator.").
-                         '</center></small></b>';
+                        _("Thread sorting is not supported by your IMAP server.") . '<br />' .
+                        _("Please contact your system administrator and report this error.") .
+                        '</center></small></b>';
                     $thread_sort_messages = 0;
                     $msort = $msgs = array();
                 } else {
@@ -446,8 +462,9 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
                 $msgs = getServerMessages($imapConnection, $start_msg, $show_num, $num_msgs, $id);
                 if ($msgs === false) {
                     echo '<b><small><center><font color=red>' .
-                         _( "Server-side sorting is not supported by your IMAP server.<br>Please report this to the system administrator.").
-                         '</center></small></b>';
+                        _( "Server-side sorting is not supported by your IMAP server.") . '<br />' .
+                        _("Please contact your system administrator and report this error.") .
+                        '</center></small></b>';
                     $sort = $server_sort_order;
                     $allow_server_sort = FALSE;
                     $msort = $msgs = array();
@@ -483,11 +500,11 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     echo '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
     echo '<tr><td>';
 
-    mail_message_listing_beginning($imapConnection, $mailbox, $sort, 
+    mail_message_listing_beginning($imapConnection, $mailbox, $sort,
                                   $msg_cnt_str, $paginator_str, $start_msg);
     echo '</td></tr>';
     /* line between the button area and the list */
-    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';  
+    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';
 
     echo '<tr><td>';
     echo '    <table width="100%" cellpadding="1" cellspacing="0" align="center"'.' border="0" bgcolor="'.$color[9].'">';
@@ -496,11 +513,11 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     echo '<tr><td>';
     printHeader($mailbox, $srt, $color, !$thread_sort_messages);
 
-    displayMessageArray($imapConnection, $num_msgs, $start_msg, 
+    displayMessageArray($imapConnection, $num_msgs, $start_msg,
 		      $msort, $mailbox, $sort, $color, $show_num,0,0);
     echo '</td></tr></table></td></tr></table>';
 
-    mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color); 
+    mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color);
     echo '</td></tr></table>';
     //$t = elapsed($start);
     //echo("elapsed time = $t seconds\n");
@@ -690,9 +707,9 @@ function mail_message_listing_beginning ($imapConnection,
                     html_tag( 'table' ,
                         html_tag( 'tr',
                             html_tag( 'td', $paginator, 'left' ) .
-                            html_tag( 'td', $msg_cnt_str, 'right' ) 
+                            html_tag( 'td', $msg_cnt_str, 'right' )
                         )
-                    , '', $color[4], 'border="0" width="100%" cellpadding="1"  cellspacing="0"' ) 
+                    , '', $color[4], 'border="0" width="100%" cellpadding="1"  cellspacing="0"' )
                 , 'left', '', '' )
             , '', $color[0] )
 	    , '', '', 'border="0" width="100%" cellpadding="1"  cellspacing="0"' );
@@ -711,9 +728,9 @@ function mail_message_listing_beginning ($imapConnection,
             )
             . html_tag( 'tr' ) ."\n"
             . html_tag( 'td', '', 'left', '', 'valign="middle" nowrap' );
-            getMbxList($imapConnection);  
-            echo getButton('SUBMIT', 'moveButton',_("Move")) . "\n";   
-            echo getButton('SUBMIT', 'attache',_("Forward")) . "\n";   
+            getMbxList($imapConnection);
+            echo getButton('SUBMIT', 'moveButton',_("Move")) . "\n";
+            echo getButton('SUBMIT', 'attache',_("Forward")) . "\n";
 
   echo "      </small></td>\n"
          . html_tag( 'td', '', 'right', '', 'nowrap' );
@@ -776,7 +793,7 @@ function mail_message_listing_beginning ($imapConnection,
 function mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color) {
   if ($num_msgs) {
     /* space between list and footer */
-    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'" COLSPAN="1">';  
+    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'" COLSPAN="1">';
 
     echo '</td></tr><tr><td>';
     echo html_tag( 'table',
@@ -808,7 +825,7 @@ function printHeader($mailbox, $sort, $color, $showsort=true) {
     $widths = array(1=>1,2=>25,3=>5,4=>0,5=>1,6=>5);
     $subjectwidth = 100;
     foreach($index_order as $item) {
-        $subjectwidth -= $widths[$item]; 
+        $subjectwidth -= $widths[$item];
     }
 
     foreach ($index_order as $item) {
@@ -947,10 +964,10 @@ function get_msgcnt_str($start_msg, $end_msg, $num_msgs) {
     /* Compute the $msg_cnt_str. */
     $result = '';
     if ($start_msg < $end_msg) {
-        $result = sprintf(_("Viewing Messages: <B>%s</B> to <B>%s</B> (%s total)"),
-                          $start_msg, $end_msg, $num_msgs);
+        $result = sprintf(_("Viewing Messages: %s to %s (%s total)"),
+                  '<b>'.$start_msg.'</b>', '<b>'.$end_msg.'</b>', $num_msgs);
     } else if ($start_msg == $end_msg) {
-        $result = sprintf(_("Viewing Message: <B>%s</B> (1 total)"), $start_msg);
+        $result = sprintf(_("Viewing Message: %s (%s total)"), '<b>'.$start_msg.'</b>', $num_msgs);
     } else {
         $result = '<br>';
     }
@@ -1103,7 +1120,7 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
 	 */
          // echo "qts =  $q1_pgs/$q2_pgs/$q3_pgs/$q4_pgs = "
          //     . ($q1_pgs + $q2_pgs + $q3_pgs + $q4_pgs) . '<br>';
-         
+
 
         /* Print out the page links from the compute page quarters. */
 
@@ -1209,7 +1226,7 @@ function processSubject($subject, $threadlevel = 0) {
      * see if this is entities-encoded string
      * If so, Iterate through the whole string, find out
      * the real number of characters, and if more
-     * than 55, substr with an updated trim value. 
+     * than 55, substr with an updated trim value.
      */
     $step = $ent_loc = 0;
     while ( $ent_loc < $trim_val && (($ent_loc = strpos($subject, '&', $ent_offset)) !== false) &&
@@ -1218,7 +1235,7 @@ function processSubject($subject, $threadlevel = 0) {
         $ent_offset  = $ent_loc_end+1;
         ++$step;
     }
-    
+
     if (($trim_val > 50) && (strlen($subject) > ($trim_val))&& (strpos($subject,';',$trim_val) < ($trim_val +6))) {
         $i = strpos($subject,';',$trim_val);
         if ($i) {
@@ -1245,7 +1262,7 @@ function processSubject($subject, $threadlevel = 0) {
 function getMbxList($imapConnection) {
     global $lastTargetMailbox;
     echo  '         <small>&nbsp;<tt><select name="targetMailbox">';
-    echo sqimap_mailbox_option_list($imapConnection, array(strtolower($lastTargetMailbox)) ); 
+    echo sqimap_mailbox_option_list($imapConnection, array(strtolower($lastTargetMailbox)) );
     echo '         </SELECT></TT>&nbsp;';
 }
 
@@ -1279,7 +1296,7 @@ function getEndMessage($start_msg, $show_num, $num_msgs) {
 
 function handleAsSent($mailbox) {
     global $handleAsSent_result;
- 
+
     /* First check if this is the sent or draft folder. */
     $handleAsSent_result = isSentMailbox($mailbox) || isDraftMailbox($mailbox);
 
@@ -1290,4 +1307,5 @@ function handleAsSent($mailbox) {
     return $handleAsSent_result;
 }
 
-?>
+// vim: et ts=4
+?>
\ No newline at end of file
