@@ -3,16 +3,20 @@
 /**
  * left_main.php
  *
- * Copyright (c) 1999-2004 The SquirrelMail Project Team
+ * Copyright (c) 1999-2005 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This is the code for the left bar. The left bar shows the folders
  * available, and has cookie information.
  *
- * $Id: left_main.php,v 1.154.2.12 2004/05/17 16:03:40 stekkel Exp $
+ * @version $Id: left_main.php,v 1.154.2.24 2005/05/31 16:50:37 kink Exp $
+ * @package squirrelmail
  */
 
-/* Path for SquirrelMail required files. */
+/**
+ * Path for SquirrelMail required files.
+ * @ignore
+ */
 define('SM_PATH','../');
 
 /* SquirrelMail required files. */
@@ -47,10 +51,10 @@ function formatMailboxName($imapConnection, $box_array) {
     $status = array('','');
     if (($unseen_notify == 2 && $real_box == 'INBOX') ||
         $unseen_notify == 3) {
-	$tmp_status = create_unseen_string($real_box, $box_array, $imapConnection, $unseen_type );
-	if ($status !== false) {
-	    $status = $tmp_status;
-	} 
+            $tmp_status = create_unseen_string($real_box, $box_array, $imapConnection, $unseen_type );
+            if ($status !== false) {
+                $status = $tmp_status;
+            }
     }
     list($unseen_string, $unseen) = $status;
     $special_color = ($use_special_folder_color && isSpecialMailbox($real_box));
@@ -59,13 +63,13 @@ function formatMailboxName($imapConnection, $box_array) {
     $line = '';
 
     /* If there are unseen message, bold the line. */
-    if ($unseen > 0) { $line .= '<B>'; }
+    if ($unseen > 0) { $line .= '<b>'; }
 
     /* Create the link for this folder. */
     if ($status !== false) {
-	$line .= '<a href="right_main.php?PG_SHOWALL=0&amp;sort=0&amp;startMessage=1&amp;mailbox='.
-                $mailboxURL.'" TARGET="right" STYLE="text-decoration:none">';
-    } 
+        $line .= '<a href="right_main.php?PG_SHOWALL=0&amp;sort=0&amp;startMessage=1&amp;mailbox='.
+                 $mailboxURL.'" target="right" style="text-decoration:none">';
+    }
     if ($special_color) {
         $line .= "<font color=\"$color[11]\">";
     }
@@ -77,18 +81,18 @@ function formatMailboxName($imapConnection, $box_array) {
     if ($special_color == TRUE)
         $line .= '</font>';
     if ($status !== false) {
-	$line .= '</a>';
+        $line .= '</a>';
     }
 
     /* If there are unseen message, close bolding. */
-    if ($unseen > 0) { $line .= "</B>"; }
+    if ($unseen > 0) { $line .= "</b>"; }
 
     /* Print unseen information. */
     if ($unseen_string != '') {
-        $line .= "&nbsp;<SMALL>$unseen_string</SMALL>";
+        $line .= "&nbsp;<small>$unseen_string</small>";
     }
 
-	/* If it's the trash folder, show a purge link when needed */
+    /* If it's the trash folder, show a purge link when needed */
     if (($move_to_trash) && ($real_box == $trash_folder)) {
         if (! isset($numMessages)) {
             $numMessages = sqimap_get_num_messages($imapConnection, $real_box);
@@ -97,8 +101,8 @@ function formatMailboxName($imapConnection, $box_array) {
         if (($numMessages > 0) or ($box_array['parent'] == 1)) {
             $urlMailbox = urlencode($real_box);
             $line .= "\n<small>\n" .
-                    "&nbsp;&nbsp;(<A HREF=\"empty_trash.php\" style=\"text-decoration:none\">"._("purge")."</A>)" .
-                    "</small>";
+                    '&nbsp;&nbsp;(<a href="empty_trash.php" style="text-decoration:none">'._("Purge").'</a>)' .
+                    '</small>';
         }
     } else {
         $line .= concat_hook_function('left_main_after_each_folder',
@@ -168,7 +172,7 @@ function compute_folder_children(&$parbox, $boxcount) {
 function create_collapse_link($boxnum) {
     global $boxes, $imapConnection, $unseen_notify, $color;
     $mailbox = urlencode($boxes[$boxnum]['unformatted']);
-        
+
     /* Create the link for this collapse link. */
     $link = '<a target="left" style="text-decoration:none" ' .
             'href="left_main.php?';
@@ -211,7 +215,7 @@ function create_unseen_string($boxName, $boxArray, $imapConnection, $unseen_type
     $status = sqimap_status_messages($imapConnection, $boxName);
     $boxUnseenCount = $status['UNSEEN'];
     if ($boxUnseenCount === false) {
-	return false;
+        return false;
     }
     if ($unseen_type == 2) {
         $boxMessageCount = $status['MESSAGES'];
@@ -231,10 +235,10 @@ function create_unseen_string($boxName, $boxArray, $imapConnection, $unseen_type
 
             /* Collect the counts for this subfolder. */
             if (($boxName != $boxes[$i]['unformatted'])
-                   && (substr($boxes[$i]['unformatted'], 0, $curBoxLength) == $boxName)
-                   && !in_array('noselect', $boxes[$i]['flags'])) {
-		$status = sqimap_status_messages($imapConnection, $boxes[$i]['unformatted']);
-		$subUnseenCount = $status['UNSEEN'];
+                    && (substr($boxes[$i]['unformatted'], 0, $curBoxLength) == $boxName)
+                    && !in_array('noselect', $boxes[$i]['flags'])) {
+                $status = sqimap_status_messages($imapConnection, $boxes[$i]['unformatted']);
+                $subUnseenCount = $status['UNSEEN'];
                 if ($unseen_type == 2) {
                     $subMessageCount = $status['MESSAGES'];;
                 }
@@ -281,231 +285,6 @@ function is_parent_box($curbox_name, $parbox_name) {
     return ($parbox_name == $actual_parname);
 }
 
-function listBoxes ($boxes, $j=0 ) {
-    global $data_dir, $username, $startmessage, $color, $unseen_notify, $unseen_type,
-        $move_to_trash, $trash_folder, $collapse_folders, $use_special_folder_color;
-	
-    $pre = '';
-    $end = '';
-    $collapse = false;
-    if ($boxes) {
-	$mailbox = $boxes->mailboxname_full;
-	$leader = '';
-	for ($k = 0; $k < $j; $k++) {
-	    $leader.= '&nbsp;&nbsp;&nbsp;';
-	}
-	$mailboxURL = urlencode($mailbox);
-
-	/* get unseen/total messages information */
-        if ($boxes->unseen) {
-	    $unseen = $boxes->unseen;
-    	    $unseen_string = "($unseen)";
-	    if ($unseen>0) $unseen_found = TRUE;
-    	    if ($boxes->total) {
-		$numMessages = $boxes->total;
-        	$unseen_string = "<font color=\"$color[11]\">($unseen/$numMessages)</font>";
-	    }	    
-	} else $unseen = 0;
-
-
-
-	if (isset($boxes->mbxs[0]) && $collapse_folders) {
-	    $collapse = getPref($data_dir, $username, 'collapse_folder_' . $mailbox);
-    	    $collapse = ($collapse == '' ? SM_BOX_UNCOLLAPSED : $collapse);
-
-	    $link = '<a target="left" style="text-decoration:none" ' .'href="left_main.php?';
-	    if ($collapse) {
-    		$link .= "unfold=$mailboxURL\">$leader +&nbsp;";
-	    } else {
-    		$link .= "fold=$mailboxURL\">$leader -&nbsp;";
-	    }
-	    $link .= '</a>';
-	    $pre .= $link;
-	} else {
-	    $pre.= $leader . '&nbsp;&nbsp;&nbsp;';
-	}
-
-
-	/* If there are unseen message, bold the line. */
-	if ($unseen > 0) { $pre .= '<B>'; }
-
-	if (($move_to_trash) && ($mailbox == $trash_folder)) {
-    	    if (! isset($numMessages)) {
-        	$status = sqimap_status_messages($imapConnection, $mailbox);
-		$numMessages = $status['MESSAGES'];
-    	    }
-
-    	    if ($numMessages > 0) {
-        	$urlMailbox = urlencode($mailbox);
-        	$pre .= "\n<small>\n" .
-                	"&nbsp;&nbsp;(<a href=\"empty_trash.php\" style=\"text-decoration:none\">"._("purge")."</a>)" .
-                	"</small>";
-    	    }
-	} else {
-	    if (!$boxes->is_noselect) {
-		$pre .= "<a href=\"right_main.php?PG_SHOWALL=0&amp;sort=0&amp;startMessage=1&amp;mailbox=$mailboxURL\" target=\"right\">";
-		$end .= '</a>';
-	    }
-	}
-
-	/* If there are unseen message, close bolding. */
-	if ($unseen > 0) { $end .= "</b>"; }
-
-	/* Print unseen information. */
-	if (isset($unseen_found) && $unseen_found) {
-    	    $end .= "&nbsp;<small>$unseen_string</small>";
-	}
-
-	$font = '';
-	$fontend = '';
-	if ($use_special_folder_color && $boxes->is_special) {
-    	    $font = "<font color=\"$color[11]\">";
-	    $fontend = "</font>";    
-	}
-	
-	if (!$boxes->is_root) { 
-	    echo "" . $pre .$font. str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$boxes->mailboxname_sub) .$fontend . $end. '<br />';
-	    $j++;
-	}
-	if (!$collapse || $boxes->is_root) {
-    	    for ($i = 0; $i <count($boxes->mbxs); $i++) {
-    		listBoxes($boxes->mbxs[$i],$j);
-    	    }
-	}    
-	
-    }
-}
-
-function ListAdvancedBoxes ($boxes, $mbx, $j='ID.0000' ) {
-    global $data_dir, $username, $startmessage, $color, $unseen_notify, $unseen_type,
-        $move_to_trash, $trash_folder, $collapse_folders, $use_special_folder_color;
-
-    /* use_folder_images only works if the images exist in ../images */
-    $use_folder_images = true;
-
-    $pre = '';
-    $end = '';
-    $collapse = false;
-    
-    if ($boxes) {
-	$mailbox = $boxes->mailboxname_full;
-	$mailboxURL = urlencode($mailbox);
-
-	/* get unseen/total messages information */
-        if ($boxes->unseen) {
-	    $unseen = $boxes->unseen;
-    	    $unseen_string = "($unseen)";
-	    if ($unseen>0) $unseen_found = TRUE;
-    	    if ($boxes->total) {
-		$numMessages = $boxes->total;
-        	$unseen_string = "<font color=\"$color[11]\">($unseen/$numMessages)</font>";
-	    }	    
-	} else $unseen = 0;
-
-	/* If there are unseen message, bold the line. */
-	if ($unseen > 0) { $pre .= '<b>'; }
-
-	/* color special boxes */
-	if ($use_special_folder_color && $boxes->is_special) {
-    	    $pre .= "<font color=\"$color[11]\">";
-	    $end .= '</font>';    
-	}
-
-	/* If there are unseen message, close bolding. */
-	if ($unseen > 0) { $end .= '</b>'; }
-
-	/* Print unseen information. */
-	if (isset($unseen_found) && $unseen_found) {
-    	    $end .= "&nbsp;$unseen_string";
-	}
-
-	if (($move_to_trash) && ($mailbox == $trash_folder)) {
-    	    if (! isset($numMessages)) {
-        	$numMessages = $boxes->total;
-    	    }
-    	    if ($numMessages > 0) {
-        	$urlMailbox = urlencode($mailbox);
-        	$pre .= "\n<small>\n" .
-                	"&nbsp;&nbsp;(<a class=\"mbx_link\" href=\"empty_trash.php\">"._("purge")."</a>)" .
-                	"</small>";
-    	    }
-	} else {
-	    if (!$boxes->is_noselect) { /* \Noselect boxes can't be selected */
-		$pre .= "<a class=\"mbx_link\" href=\"right_main.php?PG_SHOWALL=0&amp;sort=0&amp;startMessage=1&amp;mailbox=$mailboxURL\" target=\"right\">";
-		$end .= '</a>';
-	    }
-	}
-
-	if (!$boxes->is_root) {
-	    if ($use_folder_images) {
-	      if ($boxes->is_inbox) {
-		$folder_img = '../images/inbox.png';
-	      } else if ($boxes->is_sent) {
-		$folder_img = '../images/senti.png';
-	      } else if ($boxes->is_trash) {
-		$folder_img = '../images/delitem.png';
-	      } else if ($boxes->is_draft) {
-		$folder_img = '../images/draft.png';
-	      } else $folder_img = '../images/folder.png';
-	      $folder_img = '&nbsp;<img src="'.$folder_img.'" height="15" valign="center" />&nbsp;';
-	    } else $folder_img = '';
-	    if (!isset($boxes->mbxs[0])) {
-	        echo '   ' . html_tag( 'div',
-	                        $pre . $folder_img . str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$boxes->mailboxname_sub) . $end ,
-	                'left', '', 'class="mbx_sub" id="' .$j. '"' )
-		        . "\n";
-	    } else {
-    		/* get collapse information */
-		if ($collapse_folders) {
-		    $link = '<a target="left" style="text-decoration:none" ' .'href="left_main.php?';
-		    $form_entry = $j.'F';
-		    if (isset($mbx) && isset($mbx[$form_entry])) {
-		        $collapse = $mbx[$form_entry];
-			if ($collapse) {
-    			    setPref($data_dir, $username, 'collapse_folder_'.$boxes->mailboxname_full , SM_BOX_COLLAPSED);
-			} else {
-    			    setPref($data_dir, $username, 'collapse_folder_'.$boxes->mailboxname_full , SM_BOX_UNCOLLAPSED);
-			}
-		    } else {
-			$collapse = getPref($data_dir, $username, 'collapse_folder_' . $mailbox);
-    			$collapse = ($collapse == '' ? SM_BOX_UNCOLLAPSED : $collapse);
-		    }
-		    if ($collapse) {
-    			$link = '<a href="javascript:void(0)">'." <img src=\"../images/plus.png\" border=\"1\" id=$j onclick=\"hidechilds(this)\" /></a>";
-		    } else {
-    			$link = '<a href="javascript:void(0)">'."<img src=\"../images/minus.png\" border=\"1\" id=$j onclick=\"hidechilds(this)\" /></a>";
-		    }
-		    $collapse_link = $link;
-		} else $collapse_link='';
-	        echo '   ' . html_tag( 'div',
-	                        $collapse_link . $pre . $folder_img . '&nbsp;'. $boxes->mailboxname_sub . $end ,
-	                'left', '', 'class="mbx_par" id="' .$j. 'P"' )
-		        . "\n";
-		echo '   <input type="hidden" name="mbx['.$j. 'F]" value="'.$collapse.'" id="mbx['.$j.'F]" />'."\n";
-	    }
-	}
-	if ($collapse) {
-	    $visible = ' style="display:none;"';
-	} else {
-	    $visible = ' style="display:block;"';
-	}
-
-	if (isset($boxes->mbxs[0]) && !$boxes->is_root) /* mailbox contains childs */
-	    echo html_tag( 'div', '', 'left', '', 'class="par_area" id='.$j.'.0000 '. $visible ) . "\n";
-
-	    if ($j !='ID.0000') {
-	       $j = $j .'.0000';
-	}
-    	for ($i = 0; $i <count($boxes->mbxs); $i++) {
-	    $j++;
-    	    listAdvancedBoxes($boxes->mbxs[$i],$mbx,$j);
-    	}
-	if (isset($boxes->mbxs[0]) && !$boxes->is_root ) echo '</div>'."\n\n";
-    }
-}
-
-
-
 
 /* -------------------- MAIN ------------------------ */
 
@@ -537,131 +316,124 @@ if (isset($left_refresh) && ($left_refresh != '') &&
 }
 
 /**
- * $advanced_tree and $oldway are boolean vars which are default set to default 
- * SM behaviour. 
- * Setting $oldway to false causes left_main.php to use the new  experimental 
- * way of getting the mailbox-tree.
- * Setting $advanced tree to true causes SM to display a experimental 
+ * $advanced_tree is a boolean var which is set to default SM behaviour.
+ * Setting $advanced tree to true causes SM to display a experimental
  * mailbox-tree with dhtml behaviour.
- * It only works on browsers which supports css and javascript. The used 
- * javascript is experimental and doesn't support all browsers. It is tested on 
- * IE6 an Konquerer 3.0.0-2.
- * In the function ListAdvancedBoxes there is another var $use_folder_images.
- * setting this to true is only usefull if the images exists in ../images.
- * 
- * Feel free to experiment with the code and report bugs and enhancements
- * to marc@its-projects.nl
- **/ 
+ * It only works on browsers which supports css and javascript. The used
+ * javascript is experimental and doesn't support all browsers.
+ * It has been tested on IE6 an Konquerer 3.0.0-2.
+ **/
 
 $advanced_tree = false; /* set this to true if you want to see a nicer mailboxtree */
-$oldway = true; /* default SM behaviour */
 
 if ($advanced_tree) {
 $xtra .= <<<ECHO
-<script language="Javascript" TYPE="text/javascript">
+<script language="Javascript" type="text/javascript">
 
 <!--
 
     function hidechilds(el) {
-    	id = el.id+".0000";
+        id = el.id+".0000";
         form_id = "mbx[" + el.id +"F]";
-	if (document.all) {
-	    ele = document.all[id];
-	    if (ele) {
-	       if(ele.style.display == "none") {
-                  ele.style.display = "block";
-	          ele.style.visibility = "visible"
-                  el.src="../images/minus.png";
-                  document.all[form_id].value=0;
+        if (document.all) {
+            ele = document.all[id];
+            if (ele) {
+                if(ele.style.display == "none") {
+                    ele.style.display = "block";
+                    ele.style.visibility = "visible"
+                        el.src="../images/minus.png";
+                    document.all[form_id].value=0;
                } else {
                   ele.style.display = "none";
-	          ele.style.visibility = "hidden"
-	          el.src="../images/plus.png";
-	          document.all[form_id].value=1;
-	       }
-	    }
-	} else if (document.getElementById) {
+                  ele.style.visibility = "hidden"
+                      el.src="../images/plus.png";
+                  document.all[form_id].value=1;
+               }
+            }
+        } else if (document.getElementById) {
             ele = document.getElementById(id);
-	    if (ele) {
-	       if(ele.style.display == "none") {
-	          ele.style.display = "block";
-	          ele.style.visibility = "visible"
-	          el.src="../images/minus.png";
-                  document.getElementById(form_id).value=0;
-	       } else {
-	          ele.style.display = "none";
-	          ele.style.visibility = "hidden"
-	          el.src="../images/plus.png";
-                  document.getElementById(form_id).value=1;
-	       }
-	    }   
-	}
-   }
-   
-   function preload() {
-     if (!document.images) return;
-     var ar = new Array();
-     var arguments = preload.arguments;
-     for (var i = 0; i<arguments.length; i++) {
-        ar[i] = new Image();
-	ar[i].src = arguments[i];
-     }
-   }        
-	    	  
-   function buttonover(el,on) {
-      if (!on) {
-         el.style.borderColor="blue";}
-      else {
-         el.style.borderColor="orange";}
-   }
+                if (ele) {
+                    if(ele.style.display == "none") {
+                        ele.style.display = "block";
+                        ele.style.visibility = "visible"
+                            el.src="../images/minus.png";
+                        document.getElementById(form_id).value=0;
+                    } else {
+                        ele.style.display = "none";
+                        ele.style.visibility = "hidden"
+                            el.src="../images/plus.png";
+                        document.getElementById(form_id).value=1;
+                    }
+                }   
+        }
+    }
 
-   function buttonclick(el,on) {
-      if (!on) { 
-         el.style.border="groove"}
-      else {
-         el.style.border="ridge";}
-   }
+    function preload() {
+       if (!document.images) return;
+       var ar = new Array();
+       var arguments = preload.arguments;
+       for (var i = 0; i<arguments.length; i++) {
+           ar[i] = new Image();
+           ar[i].src = arguments[i];
+       }
+    }
 
-   function hideframe(hide) {
+    function buttonover(el,on) {
+        if (!on) {
+            el.style.borderColor="blue";
+        } else {
+            el.style.borderColor="orange";
+        }
+    }
+
+    function buttonclick(el,on) {
+        if (!on) { 
+            el.style.border="groove"
+        } else {
+            el.style.border="ridge";
+        }
+    }
+
+    function hideframe(hide) {
    
 ECHO;
 $xtra .= "      left_size = \"$left_size\";\n";
 $xtra .= <<<ECHO
-      if (document.all) {
-    	masterf = window.parent.document.all["fs1"];
-	leftf = window.parent.document.all["left"];
-	leftcontent = document.all["leftframe"];
-	leftbutton = document.all["showf"];
-      } else if (document.getElementById) {
-	masterf = window.parent.document.getElementById("fs1");
-	leftf = window.parent.document.getElementById("left");
-	leftcontent = document.getElementById("leftframe");
-	leftbutton = document.getElementById("showf");
-      } else {
-        return false;
-      }	
-      if(hide) {
-         new_col = calc_col("20");
-         masterf.cols = new_col;
-	 document.body.scrollLeft=0;
-	 document.body.style.overflow='hidden';
-	 leftcontent.style.display = 'none';
-	 leftbutton.style.display='block';
-      } else {
-         masterf.cols = calc_col(left_size);
-	 document.body.style.overflow='';
-	 leftbutton.style.display='none';
-	 leftcontent.style.display='block';
-	 
+        if (document.all) {
+            masterf = window.parent.document.all["fs1"];
+            leftf = window.parent.document.all["left"];
+            leftcontent = document.all["leftframe"];
+            leftbutton = document.all["showf"];
+        } else if (document.getElementById) {
+            masterf = window.parent.document.getElementById("fs1");
+            leftf = window.parent.document.getElementById("left");
+            leftcontent = document.getElementById("leftframe");
+            leftbutton = document.getElementById("showf");
+        } else {
+            return false;
+        }
+        if(hide) {
+            new_col = calc_col("20");
+            masterf.cols = new_col;
+            document.body.scrollLeft=0;
+            document.body.style.overflow='hidden';
+            leftcontent.style.display = 'none';
+            leftbutton.style.display='block';
+        } else {
+            masterf.cols = calc_col(left_size);
+            document.body.style.overflow='';
+            leftbutton.style.display='none';
+            leftcontent.style.display='block';
+
       }
    }
-   
+
    function calc_col(c_w) {
 
 ECHO;
    if ($location_of_bar == 'right') {
        $xtra .= '     right=true;';
-   } else {    
+   } else {
        $xtra .= '     right=false;';
    }
    $xtra .= "\n";
@@ -672,42 +444,42 @@ $xtra .= <<<ECHO
          new_col = c_w+',*';
      }
      return new_col;
-   }	 
-         
+   }
+
    function resizeframe(direction) {
      if (document.all) {
-    	masterf = window.parent.document.all["fs1"];
+        masterf = window.parent.document.all["fs1"];
      } else if (document.getElementById) {
-	window.parent.document.getElementById("fs1");
+        window.parent.document.getElementById("fs1");
      } else {
         return false;
      }
-     
+
 ECHO;
    if ($location_of_bar == 'right') {
        $xtra .= '  colPat=/^\*,(\d+)$/;';
-   } else {    
+   } else {
        $xtra .= '  colPat=/^(\d+),.*$/;';
    }
    $xtra .= "\n";
-  
+
 $xtra .= <<<ECHO
      old_col = masterf.cols;
      colPat.exec(old_col);
-     
+
      if (direction) {
         new_col_width = parseInt(RegExp.$1) + 25;
-	
+
      } else {
         if (parseInt(RegExp.$1) > 35) {
            new_col_width = parseInt(RegExp.$1) - 25;
         }
      }
-     masterf.cols = calc_col(new_col_width);	
+     masterf.cols = calc_col(new_col_width);
    }
 
 //-->
-   
+
 </script>
 
 ECHO;
@@ -725,16 +497,18 @@ $xtra .= <<<ECHO
 
   .button {
      border:outset;
-     border-color:blue;
-     background:white;
+     border-color: $color[9];
+     background:$color[0];
+     color:$color[6];
      width:99%;
      heigth:99%;
   }
 
   .mbx_par {
-     font-size:0.8em;
+     font-size:1.0em;
      margin-left:4px;
      margin-right:0px;
+     white-space: nowrap;
   }
 
   a.mbx_link {
@@ -756,7 +530,8 @@ $xtra .= <<<ECHO
      padding-right:0px;
      margin-left:4px;
      margin-right:0px;
-     font-size:0.7em;
+     font-size:0.9em;
+     white-space: nowrap;
   }
 
   .par_area {
@@ -767,10 +542,10 @@ $xtra .= <<<ECHO
      padding-bottom:5px;
      border-left: solid;
      border-left-width:0.1em;
-     border-left-color:blue;
+     border-left-color:$color[9];
      border-bottom: solid;
      border-bottom-width:0.1em;
-     border-bottom-color:blue;
+     border-bottom-color:$color[9];
      display: block;
   }
 
@@ -782,7 +557,7 @@ $xtra .= <<<ECHO
      padding-left:4px;
      border: groove;
      border-width:0.1em;
-     border-color:green;
+     border-color:$color[9];
      background: $color[0];
   }
 
@@ -822,7 +597,6 @@ if ($auto_create_special && !$auto_create_done) {
      */
     if ($advanced_tree) {
         // do nothing, caching not seported yet.
-        //$boxes = sqimap_mailbox_tree($imapConnection);
     } else {
         $boxes = sqimap_mailbox_list($imapConnection,true);
     }
@@ -832,24 +606,27 @@ echo "\n<body bgcolor=\"$color[3]\" text=\"$color[6]\" link=\"$color[6]\" vlink=
 
 do_hook('left_main_before');
 if ($advanced_tree) {
-   /* nice future feature, needs layout !! volunteers?   */  
+   /* nice future feature, needs layout !! volunteers?   */
    $right_pos = $left_size - 20;
-   echo '<div style="position:absolute;top:0;border=solid;border-width:0.1em;border-color:blue;"><div ID="hidef" style="width=20;font-size:12"><A HREF="javascript:hideframe(true)"><b><<</b></a></div>';
-   echo '<div ID="showf" style="width=20;font-size:12;display:none;"><a href="javascript:hideframe(false)"><b>>></b></a></div>';
-   echo '<div ID="incrf" style="width=20;font-size:12"><a href="javascript:resizeframe(true)"><b>></b></a></div>';
-   echo '<div ID="decrf" style="width=20;font-size:12"><a href="javascript:resizeframe(false)"><b><</b></a></div></div>';
-   echo '<div ID="leftframe"><br /><br />';
+/*   echo '<div style="position:absolute;top:0;border=solid;border-width:0.1em;border-color:blue;"><div id="hidef" style="width=20;font-size:12"><a href="javascript:hideframe(true)"><b>&lt;&lt;</b></a></div>';
+   echo '<div id="showf" style="width=20;font-size:12;display:none;"><a href="javascript:hideframe(false)"><b>&gt;&gt;</b></a></div>';
+   echo '<div id="incrf" style="width=20;font-size:12"><a href="javascript:resizeframe(true)"><b>&gt;</b></a></div>';
+   echo '<div id="decrf" style="width=20;font-size:12"><a href="javascript:resizeframe(false)"><b>&lt;</b></a></div></div>';
+   echo '<div id="leftframe"><br /><br />';*/
 }
 
-echo "\n\n" . html_tag( 'table', '', 'left', '', 'border="0" cellspacing="0" cellpadding="0" width="99%"' ) . 
-    html_tag( 'tr' ) . 
-    html_tag( 'td', '', 'left' ) . 
-    '<center><font size="4"><b>'. _("Folders") . "</b><br /></font>\n\n";
+echo "\n\n" . html_tag( 'table', '', 'left', '', 'border="0" cellspacing="0" cellpadding="0" width="99%"' ) .
+    html_tag( 'tr' ) .
+    html_tag( 'td', '', 'left' ) .
+    html_tag( 'table', '', '', '', 'border="0" cellspacing="0" cellpadding="0"' ) .
+    html_tag( 'tr' ) .
+    html_tag( 'td', '', 'center' ) .
+    '<font size="4"><b>'. _("Folders") . "</b><br /></font>\n\n";
 
 if ($date_format != 6) {
     /* First, display the clock. */
     if ($hour_format == 1) {
-        $hr = 'G:i';
+        $hr = 'H:i';
         if ($date_format == 4) {
             $hr .= ':s';
         }
@@ -863,8 +640,8 @@ if ($date_format != 6) {
 
     switch( $date_format ) {
     case 0:
-	$clk = date('Y-m-d '.$hr. ' T', time());
-	break;
+        $clk = date('Y-m-d '.$hr. ' T', time());
+        break;
     case 1:
         $clk = date('m/d/y '.$hr, time());
         break;
@@ -880,14 +657,14 @@ if ($date_format != 6) {
     }
     $clk = str_replace(' ','&nbsp;',$clk);
 
-    echo '<center><small>' . str_replace(' ','&nbsp;',_("Last Refresh")) .
-         ": $clk</small></center>";
+    echo '<small><span style="white-space: nowrap;">' 
+       . str_replace(' ', '&nbsp;', _("Last Refresh")) 
+       . ":</span><br /><span style=\"white-space: nowrap;\">$clk</span></small><br />";
 }
 
 /* Next, display the refresh button. */
-echo '<small>(<a href="../src/left_main.php" target="left">'.
-     _("refresh folder list") . '</a>)</small></center><br />';
-// for SM 1.4.3:  _("Check mail")
+echo '<small style="white-space: nowrap;">(<a href="../src/left_main.php" target="left">'.
+     _("Check mail") . '</a>)</small></td></tr></table><br />';
 
 /* Lastly, display the folder list. */
 if ( $collapse_folders ) {
@@ -899,8 +676,6 @@ if ( $collapse_folders ) {
     }
 }
 
-if ($oldway) {  /* normal behaviour SM */
- 
 sqgetGlobalVar('force_refresh',$force_refresh,SQ_GET);
 if (!isset($boxes)) { // auto_create_done
     $boxes = sqimap_mailbox_list($imapConnection,$force_refresh);
@@ -916,11 +691,11 @@ while ($curbox < $boxcount) {
     compute_folder_children($curbox, $boxcount);
 }
 
-
 for ($i = 0; $i < count($boxes); $i++) {
     if ( $boxes[$i]['visible'] ) {
         $mailbox = $boxes[$i]['formatted'];
-        $mblevel = substr_count($boxes[$i]['unformatted'], $delimiter) + 1;
+	// remove folder_prefix using substr so folders aren't indented unnecessarily
+        $mblevel = substr_count(substr($boxes[$i]['unformatted'], strlen($folder_prefix)), $delimiter) + 1;
 
         /* Create the prefix for the folder name and link. */
         $prefix = str_repeat('  ',$mblevel);
@@ -930,7 +705,7 @@ for ($i = 0; $i < count($boxes); $i++) {
         } else {
             $prefix = str_replace(' ','&nbsp;',$prefix);
         }
-        $line = "<nobr><tt>$prefix</tt>";
+        $line = "<span style=\"white-space: nowrap;\"><tt>$prefix</tt>";
 
         /* Add the folder name and link. */
         if (! isset($color[15])) {
@@ -953,41 +728,16 @@ for ($i = 0; $i < count($boxes); $i++) {
         }
 
         /* Put the final touches on our folder line. */
-        $line .= "</nobr><br>\n";
+        $line .= "</span><br />\n";
 
         /* Output the line for this folder. */
         echo $line;
-
-
-
     }
 }
-} else {  /* expiremental code */ 
-    $boxes = sqimap_mailbox_tree($imapConnection);
-    if (isset($advanced_tree) && $advanced_tree) {
-	echo '<form name="collapse" action="left_main.php" method="post" ' .
-            'enctype="multipart/form-data"'."\n";
-	echo '<small><button type="submit" class="button" onmouseover="buttonover(this,true)" onmouseout="buttonover(this,false)" onmousedown="buttonclick(this,true)" onmouseup="buttonclick(this,false)">'. _("Save folder tree") .'</button><br /><br />';
-	echo '<div id="mailboxes" class="mailboxes">'."\n\n";
-	if (!isset($mbx)) $mbx=NULL; 
-	    ListAdvancedBoxes($boxes, $mbx);
-	echo '</div></small>'."\n";
-	echo '</form>'."\n";
-    } else {
-	ListBoxes($boxes);
-    }
-} /* if ($oldway) else ... */
-
-       /* Next, display the refresh button. */
-//       echo '<br><center><small>(<a href="../src/left_main.php?force_refresh=1" target="left">'.
-//          _("refresh folder list") . '</a>)</small></center><br />';
-
-
 
 do_hook('left_main_after');
 sqimap_logout($imapConnection);
 
-echo '</td></tr></table>' . "\n".
-    "</div></body></html>\n";
-
 ?>
+</td></tr></table>
+</body></html>
